@@ -233,12 +233,20 @@ void Adif::setSponsorsList()
 
 bool Adif::isValidFreq(const QString &_b)
 {
+    //qDebug() << Q_FUNC_INFO << ": freq: " << _b;
     bool _ok;
     double f = _b.toDouble(&_ok);
     if ((_ok) && f>0)
     {
+        //qDebug() << Q_FUNC_INFO << ": Freq OK" ;
         return true;
     }
+   /* if (!_ok)
+        //qDebug() << Q_FUNC_INFO << ": Freq NOK: NOK" ;
+    if (f<=0)
+        //qDebug() << Q_FUNC_INFO << ": Freq NOK: f=0" ;
+    else
+        //qDebug() << Q_FUNC_INFO << ": Freq NOK: NOT-KNOWN" ;*/
     return false;
 }
 
@@ -246,6 +254,120 @@ bool Adif::isValidPower(const QString &_b)
 {
     return (_b.toDouble()>0);
 }
+
+QString Adif::getADIFBoolFromBool(const bool _b)
+{// Will produce the ADIF format if a bool is received
+    if (_b)
+        return "Y";
+    return "N";
+}
+
+
+bool Adif::isValidK_Index(const QString &_b)
+{
+    return ((_b.toInt()>=0) && (_b.toInt()<=9));
+}
+
+bool Adif::isValidCQz(const QString &_b)
+{
+   return ((_b.toInt()>=1) && (_b.toInt()<=40));
+}
+
+bool Adif::isValidITUz(const QString &_b)
+{
+    return ((_b.toInt()>=1) && (_b.toInt()<=90));
+}
+
+bool Adif::isValidDXCC(const QString &_b)
+{
+    return ((_b.toInt()>=0) && (_b.toInt()<=522));
+}
+
+bool Adif::isValidAge(const QString &_b)
+{
+    return ((_b.toInt()>=0) && (_b.toInt()<=120));
+}
+
+bool Adif::isValidAnt_EL(const QString &_b)
+{
+    return ((_b.toInt()>=-90) && (_b.toInt()<=900));
+}
+
+bool Adif::isValidAnt_AZ(const QString &_b)
+{
+    return ((_b.toInt()>=0) && (_b.toInt()<=360));
+}
+
+bool Adif::isValidA_Index(const QString &_b)
+{
+    return ((_b.toInt()>=0) && (_b.toInt()<=400));
+}
+
+bool Adif::isValidDistance(const QString &_b)
+{
+    return (_b.toDouble()>0);
+}
+
+bool Adif::isValidIOTA_islandID(const QString &_b)
+{
+    return ((_b.toInt()>=1) && (_b.toInt()<=90));
+}
+
+bool Adif::isValidNRBursts(const QString &_b)
+{
+    return (_b.toInt()>0);
+}
+
+bool Adif::isValidPings(const QString &_b)
+{
+    return (_b.toInt()>0);
+}
+
+bool Adif::isValidSFI(const QString &_b)
+{
+    return ((_b.toInt()>=0) && (_b.toInt()<=300));
+}
+
+bool Adif::isValidSTX(const QString &_b)
+{
+    return (_b.toInt()>=0);
+}
+
+bool Adif::isValidSRX(const QString &_b)
+{
+    return (_b.toInt()>=0);
+}
+
+bool Adif::isValidFISTS(const QString &_b)
+{
+   return (_b.toInt()>0);
+}
+
+bool Adif::isValidUKSMG(const QString &_b)
+{
+    return (_b.toInt()>0);
+}
+
+bool Adif::isValidTenTen(const QString &_b)
+{
+    return (_b.toInt()>0);
+}
+
+bool Adif::isValidLogId(const QString &_b)
+{
+    return (_b.toInt()>0);
+}
+
+bool Adif::isValidAntPath(const QString &_s)
+{
+    return ((_s == "G") || (_s == "O") || (_s == "S") || (_s == "L"));
+}
+
+bool Adif::isValidQSO_COMPLETE(const QString &_s)
+{    // "Y", "N", "NIL", "?"
+    return ((_s == "Y") || (_s == "N") || (_s == "NIL") || (_s == "?"));
+}
+
 /*
 bool Utilities::isValidComment(const QString &_b)
 {
@@ -464,11 +586,6 @@ QString Utilities::getADIFField(const QString &_fieldName, const QString &_data)
     return QString ("<%1:%2>%3 ").arg(_fieldName).arg(_data.length ()).arg(_data);
 }
 
-bool Utilities::isValidAntPath(const QString &_s)
-{
-   return ((_s == "G") || (_s == "O") || (_s == "S") || (_s == "L"));
-}
-
 bool Utilities::isValidARRLSect(const QString &_s)
 {
     return (ARRL_sects.contains (_s.toUpper ()));
@@ -504,14 +621,22 @@ bool Utilities::isValidSponsor(const QString &_s)
 QString Adif::getADIFField(const QString &_fieldName, const QString &_data)
 {// Receives the ADIF field and the data and returns the ADIF field with a blank space at the end.
     // Check if _fieldName is a valid ADIF
+    //qDebug() << Q_FUNC_INFO << " - " << _fieldName << "/" << _data;
+    if ((_data.length()<=0) || (_data.isNull()))
+    {
+        //qDebug() << Q_FUNC_INFO << " - Not Valid";
+        return QString();
+    }
     if (ADIFHash.empty()) {
         InitializeHash();
     }
-    if (!ADIFHash.contains(_fieldName)) {
+
+    QString fieldN = _fieldName.toUpper();
+    if (!ADIFHash.contains(fieldN)) {
         //qDebug() << Q_FUNC_INFO << " - No valid ADIF: " << _fieldName;
         return QString();
     }
-    return QString ("<%1:%2>%3 ").arg(_fieldName).arg(_data.length ()).arg(_data);
+    return QString ("<%1:%2>%3 ").arg(fieldN).arg(_data.length ()).arg(_data);
 }
 
 bool Adif::isValidCall(const QString &_c)
