@@ -26,24 +26,17 @@
 
 #include "statsqsosperhourbarchartwidget.h"
 
-
-StatsQSOsPerHourBarChartWidget::StatsQSOsPerHourBarChartWidget()
-{
-    dataProxy = new DataProxy_SQLite(Q_FUNC_INFO);
-    chart = new QChart();
-    chartView = new QChartView(chart);
-}
-
 StatsQSOsPerHourBarChartWidget::StatsQSOsPerHourBarChartWidget(DataProxy_SQLite *dp, QWidget *parent)
 {
+    Q_UNUSED(parent);
 #ifdef QT_DEBUG
-    //qDebug() << "StatsDxccOnSatsWidget::StatsDxccOnSatsWidget" << QT_ENDL;
+    //qDebug() << "StatsDxccOnSatsWidget::StatsDxccOnSatsWidget";
 #else
 #endif
 
     dataProxy = dp;
-    chart = new QChart();
-    chartView = new QChartView(chart);
+    //chart = new QChart();
+    chartView = new QChartView();
 
     createUI();
     //prepareChart();
@@ -55,9 +48,6 @@ StatsQSOsPerHourBarChartWidget::~StatsQSOsPerHourBarChartWidget()
 
 void StatsQSOsPerHourBarChartWidget::createUI()
 {
-    chart->setAnimationOptions(QChart::SeriesAnimations);
-    chart->legend()->setVisible(true);
-    chart->legend()->setAlignment(Qt::AlignBottom);
     chartView->setRenderHint(QPainter::Antialiasing);
 
     QVBoxLayout *graphLayout = new QVBoxLayout;
@@ -67,7 +57,10 @@ void StatsQSOsPerHourBarChartWidget::createUI()
 
 void StatsQSOsPerHourBarChartWidget::prepareChart(const int _log)
 {
-
+    QChart *chart = new QChart();
+    chart->setAnimationOptions(QChart::SeriesAnimations);
+    chart->legend()->setVisible(true);
+    chart->legend()->setAlignment(Qt::AlignBottom);
     QString categoriesTitle;
     QString categoriesElem;
     QStringList categories;
@@ -75,7 +68,7 @@ void StatsQSOsPerHourBarChartWidget::prepareChart(const int _log)
     QBarCategoryAxis *axis = new QBarCategoryAxis();
     QString aux;
 
-    int numberPerX = 0;
+    //int numberPerX = 0;
     chart->removeAllSeries();
     categoriesTitle = QString();
     categoriesElem = QString();
@@ -99,9 +92,9 @@ void StatsQSOsPerHourBarChartWidget::prepareChart(const int _log)
      aux.clear();
      for (int i = 0; i < categories.count(); i++ )
      {
-         numberPerX = dataProxy->getQSOsAtHour((categories.at(i)).toInt(), _log);
-            //qDebug() << "BarChartStats::prepareChart SelectedGrapth-7: QSO/hour: " << categories.at(i) << " - " << QString::number(numberPerX) << QT_ENDL;
-         *set0 << numberPerX;
+         *set0 << dataProxy->getQSOsAtHour((categories.at(i)).toInt(), _log);
+            //qDebug() << "BarChartStats::prepareChart SelectedGrapth-7: QSO/hour: " << categories.at(i) << " - " << QString::number(numberPerX);
+         //*set0 << numberPerX;
          //numberPerX = 0;
 
 
@@ -113,7 +106,7 @@ void StatsQSOsPerHourBarChartWidget::prepareChart(const int _log)
          {
              i = categories.count();
          }
-            //qDebug() << "BarChartStats::prepareChart CQz: " << QString::number((categories.at(i)).toInt()) << "/" << QString::number(numberPerX) << QT_ENDL;
+            //qDebug() << "BarChartStats::prepareChart CQz: " << QString::number((categories.at(i)).toInt()) << "/" << QString::number(numberPerX);
      }
 
     sum = set0->sum();
@@ -128,7 +121,7 @@ void StatsQSOsPerHourBarChartWidget::prepareChart(const int _log)
     //chart->createDefaultAxes();
     //series->attachAxis(axis);
     chart->addAxis(axis, Qt::AlignBottom);
-    //chart->setAxisX(axis, series);
+    chartView->setChart (chart);
 }
 
 
