@@ -26,20 +26,13 @@
 
 #include "statsworkedsentpiechartwidget.h"
 
-StatsWorkedSentPieChartWidget::StatsWorkedSentPieChartWidget()
-{
-    dataProxy = new DataProxy_SQLite(Q_FUNC_INFO);
-    chart = new QChart();
-    chartView = new QChartView(chart);
-}
-
 StatsWorkedSentPieChartWidget::StatsWorkedSentPieChartWidget(DataProxy_SQLite *dp, QWidget *parent)
 {
-      //qDebug() << "StatsWorkedSentPieChartWidget::StatsWorkedSentPieChartWidget" << QT_ENDL;
-
+      //qDebug() << "StatsWorkedSentPieChartWidget::StatsWorkedSentPieChartWidget";
+    Q_UNUSED(parent);
     dataProxy = dp;
-    chart = new QChart();
-    chartView = new QChartView(chart);
+    //chart = new QChart();
+    chartView = new QChartView();
 
     createUI();
     //prepareChart();
@@ -52,9 +45,6 @@ StatsWorkedSentPieChartWidget::~StatsWorkedSentPieChartWidget()
 
 void StatsWorkedSentPieChartWidget::createUI()
 {
-    chart->setAnimationOptions(QChart::SeriesAnimations);
-    chart->legend()->setVisible(true);
-    chart->legend()->setAlignment(Qt::AlignBottom);
     chartView->setRenderHint(QPainter::Antialiasing);
 
     QVBoxLayout *graphLayout = new QVBoxLayout;
@@ -64,13 +54,17 @@ void StatsWorkedSentPieChartWidget::createUI()
 
 void StatsWorkedSentPieChartWidget::prepareChart(const int _log)
 {
+    QChart *chart = new QChart();
+    chart->setAnimationOptions(QChart::SeriesAnimations);
+    chart->legend()->setVisible(true);
+    chart->legend()->setAlignment(Qt::AlignBottom);
     QPieSeries *series = new QPieSeries();
     //PieSlice append(string label, real value)
     int qsos = dataProxy->getHowManyQSOInLog(_log);
     int confirmed = dataProxy->getHowManyQSLSentInLog(_log);
-       //qDebug() << "QSOs: " << QString::number(qsos) << QT_ENDL;
-       //qDebug() << "Confirmed: " << QString::number(confirmed) << QT_ENDL;
-       //qDebug() << "Worked: " << QString::number(qsos - confirmed) << QT_ENDL;
+       //qDebug() << "QSOs: " << QString::number(qsos);
+       //qDebug() << "Confirmed: " << QString::number(confirmed);
+       //qDebug() << "Worked: " << QString::number(qsos - confirmed);
 
     series->append(tr("Worked - %1").arg(qsos), qsos);
     series->append(tr("Sent - %2").arg(confirmed), confirmed);
@@ -93,6 +87,6 @@ void StatsWorkedSentPieChartWidget::prepareChart(const int _log)
     chart->legend()->hide();
 
     chartView->setRenderHint(QPainter::Antialiasing);
-
+    chartView->setChart (chart);
 
 }
