@@ -32,7 +32,7 @@
 MainWindowInputQSL::MainWindowInputQSL(DataProxy_SQLite *dp, QWidget *parent) :
     QWidget(parent)
 {
-       //qDebug() << "MainWindowInputQSL::MainWindowInputQSL"   << QT_ENDL;
+       //qDebug() << "MainWindowInputQSL::MainWindowInputQSL"  ;
     util = new Utilities(Q_FUNC_INFO);
     qslSentComboBox = new QComboBox;
     qslRecComboBox = new QComboBox;
@@ -50,8 +50,7 @@ MainWindowInputQSL::MainWindowInputQSL(DataProxy_SQLite *dp, QWidget *parent) :
     createUI();
     setDefaultData();
     clear();
-       //qDebug() << "MainWindowInputQSL::MainWindowInputQSL - END"   << QT_ENDL;
-
+       //qDebug() << "MainWindowInputQSL::MainWindowInputQSL - END"  ;
 }
 
 MainWindowInputQSL::~MainWindowInputQSL()
@@ -117,7 +116,6 @@ void MainWindowInputQSL::createUI()
 
 void MainWindowInputQSL::setDefaultData()
 {
-
     qslSentStatusList.clear();
     qslRcvdStatusList.clear();
     qslViaList.clear();
@@ -133,9 +131,8 @@ void MainWindowInputQSL::setDefaultData()
 
     qslSentQDateEdit->setDate(util->getDefaultDate());
     qslRecQDateEdit->setDate(util->getDefaultDate());
-
-
 }
+
 void MainWindowInputQSL::clear()
 {
     qslSentComboBox->setCurrentIndex(1);
@@ -148,7 +145,6 @@ void MainWindowInputQSL::clear()
 
     qslmsgTextEdit->clear();
     qslViaLineEdit->clear();
-
 }
 
 void MainWindowInputQSL::qslViaClear()
@@ -174,7 +170,7 @@ QString MainWindowInputQSL::getSentVia()
 {
     QString _pm = QString();
     _pm = (((qslSentViaComboBox->currentText()).split('-')).at(0)).simplified();
-       //qDebug() << "MainWindow::getSentVia: " << _pm << QT_ENDL;
+       //qDebug() << "MainWindow::getSentVia: " << _pm;
      return _pm;
 }
 
@@ -182,7 +178,7 @@ QString MainWindowInputQSL::getRecVia()
 {
     QString _pm = QString();
     _pm = (((qslRecViaComboBox->currentText()).split('-')).at(0)).simplified();
-       //qDebug() << "MainWindowInputQSL::getRecVia: " << _pm << QT_ENDL;
+       //qDebug() << "MainWindowInputQSL::getRecVia: " << _pm;
      return _pm;
 }
 
@@ -235,7 +231,7 @@ void MainWindowInputQSL::setQSLRecVia(const QString &_qs)
 
 void MainWindowInputQSL::setQSLSenVia(const QString &_qs)
 {
-       //qDebug() << "MainWindowInputQSL::setQSLSenVia: " << _qs << QT_ENDL;
+       //qDebug() << "MainWindowInputQSL::setQSLSenVia: " << _qs;
     if(( qslSentViaComboBox->findText(_qs+" -", Qt::MatchStartsWith))>=0)
     {
         qslSentViaComboBox->setCurrentIndex( qslSentViaComboBox->findText(_qs+" -", Qt::MatchStartsWith));
@@ -248,7 +244,6 @@ void MainWindowInputQSL::setQSLSenVia(const QString &_qs)
 
 void MainWindowInputQSL::setQSLVia(const QString &_qs, QColor qColor)
 {
-
     palette.setColor(QPalette::Text, qColor);
     qslViaLineEdit->setPalette(palette);
 
@@ -260,7 +255,6 @@ void MainWindowInputQSL::setQSLVia(const QString &_qs, QColor qColor)
     {
         qslViaLineEdit->clear();
     }
-
 }
 
 void MainWindowInputQSL::setQSLMsg(const QString &_qs)
@@ -279,7 +273,6 @@ void MainWindowInputQSL::setQSLMsg(const QString &_qs)
 QDate MainWindowInputQSL::getQSLRecDate()
 {
     return qslRecQDateEdit->date();
-
 }
 
 QDate MainWindowInputQSL::getQSLSenDate()
@@ -313,13 +306,13 @@ void MainWindowInputQSL::setQSLSenDate(const QDate _qs)
 
 void MainWindowInputQSL::slotQSLViaTextChanged()
 {
-       //qDebug() << "MainWindow::slotQSLViaTextChanged: " << qslViaLineEdit->text() << " / Length: " << QString::number((qslViaLineEdit->text()).size()) << QT_ENDL;
+       //qDebug() << "MainWindow::slotQSLViaTextChanged: " << qslViaLineEdit->text() << " / Length: " << QString::number((qslViaLineEdit->text()).size());
     qslViaLineEdit->setText((util->getClearSQLi(qslViaLineEdit->text())).toUpper());
 }
 
 
-void MainWindowInputQSL::slotQSLSentComboBoxChanged(){
-
+void MainWindowInputQSL::slotQSLSentComboBoxChanged()
+{
     int i = qslSentComboBox->currentIndex();
 //{Y, N, R, I, V}
     //(QSLSDATE is only valid if QSL_SENT is Y-0, Q-3, or I-4)
@@ -351,8 +344,8 @@ void MainWindowInputQSL::slotQSLSentComboBoxChanged(){
 }
 
 
-void MainWindowInputQSL::slotQSLRecvComboBoxChanged(){
-
+void MainWindowInputQSL::slotQSLRecvComboBoxChanged()
+{
     int i = qslRecComboBox->currentIndex();
 //{Y, N, R, I, V}
     //(QSLSDATE is only valid if QSL_SENT is Y-0, Q-3, or I-4)
