@@ -31,6 +31,8 @@ QSO::QSO()
     qsoId = -1;
     util = new Utilities(Q_FUNC_INFO);
     util->setCallValidation(false);
+    //db = new DataBase(Q_FUNC_INFO, "1", util->getKLogDBFile());
+    //db = new DataBase(Q_FUNC_INFO, klogVersion, util->getKLogDBFile());
 }
 
 QSO::~QSO()
@@ -53,14 +55,18 @@ void QSO::logEvent(const QString &_func, const QString &_msg,  DebugLogLevel _le
 
 bool QSO::isComplete()
 {
-    return (haveBand && haveMode && haveDateTime && haveCall);
+    return (haveBand && (haveMode || haveSubMode) && haveDateTime && haveCall);
 }
 
 void QSO::clear()
-{
+{   // When we clear a QSO, we put data that is not valid for a QSO, if possible.
+    // so no data that has not been saved by the user is "populated automatically" by KLog
+    // without the user's knowledge or intention
+
     logEvent (Q_FUNC_INFO, "Start", Debug);
     haveBand = false;
     haveMode = false;
+    haveSubMode = false;
     haveDateTime = false;
     haveCall = false;
 
@@ -79,10 +85,10 @@ void QSO::clear()
 
     // VARIABLES for ADIF //////////
     address = QString();
-    age = 0.0;
-    a_index = -1;
-    ant_az = 0;
-    ant_el = 0;
+    age = 0;
+    a_index = 0;
+    ant_az = 0.0;
+    ant_el = 0.0;
     ant_path = QString();
     arrl_sect = QString();
     award_submitted = QString();
@@ -101,12 +107,12 @@ void QSO::clear()
     contacted_op = QString();
     contest_id = QString();
     country = QString();
-    cqz = -1;
+    cqz = 0;
     credit_granted = QString();
     credit_submitted = QString();
     darc_dok = QString();
-    distance = 0.0;
-    dxcc = -1;
+    distance = 0;
+    dxcc = 0;
     email = QString();
     ownerCall = QString();
     contacted_owner = QString();
@@ -114,27 +120,26 @@ void QSO::clear()
     eQSLSDate = QDate();
     eqsl_qsl_rcvd = QString();
     eqsl_qsl_sent = QString();
-    fists = -1;
-    fists_cc = -1;
+    fists = 0;
+    fists_cc = 0;
     forceInit = false;
-    freq = -1.0;
-    freq_rx = -1.0;
-    freq_tx = -1.0;
+    freq_tx = 0;
+    freq_rx = 0;
     gridsquare = QString();
     operatorCall = QString();
     hrdlogUploadDate = QDate();
     hrdlog_status = QString();
     iota = QString();
-    iota_ID = -1;
-    itu_zone = -1;
-    k_index = -1;
+    iota_ID = 0;
+    itu_zone = 0;
+    k_index = 0;
     latitude = QString();
     longitude = QString();
     QSLLoTWRDate = QDate();
     QSLLoTWSDate = QDate();
     lotw_qsl_rcvd = QString();
     lotw_qsl_sent = QString();
-    max_bursts = -1;
+    max_bursts = 0;
     mode = QString();
     ms_shower = QString();
     my_antenna = QString();
@@ -142,13 +147,13 @@ void QSO::clear()
     my_city = QString();
     my_county = QString();
     my_country = QString();
-    my_cqz = -1;
-    my_dxcc = -1;
-    my_fists = -1;
+    my_cqz = 0;
+    my_dxcc = 0;
+    my_fists = 0;
     my_gridsquare = QString();
     my_iota = QString();
-    my_iota_ID = -1;
-    my_itu_zone = -1;
+    my_iota_ID = 0;
+    my_itu_zone = 0;
     my_latitude = QString();
     my_longitude = QString();
     my_name = QString();
@@ -183,10 +188,10 @@ void QSO::clear()
     qslSenVia = QString();
     qslRecVia = QString();
     qslVia = QString();
-    qso_complete = QString();
+    qso_complete = qso_complete = util->getQSO_CompleteFromADIF("Y");
     qso_dateTime = QDateTime();
     qso_date_off = QDate();
-    qso_random = false;
+    qso_random = true;
     qth = QString();
     region = QString();
     rig = QString();
@@ -195,23 +200,23 @@ void QSO::clear()
     pwr_rx = 0.0;
     satMode = QString();
     satName = QString();
-    sfi = -1;
+    sfi = 0;
     sig = QString();
     sig_info = QString();
     silent_key = false;
     skcc = QString();
     sota_ref = QString();
-    srx = -1;
+    srx = 0;
     srx_string = QString();
     state = QString();
-    stx = -1;
+    stx = 0;
     stx_string = QString();
     submode = QString();
     swl = false;
-    ten_ten = -1;
+    ten_ten = 0;
     qso_time_off = QTime();
     pwr_tx = 0.0;
-    uksmg = -1;
+    uksmg = 0;
     usaca_counties = QString();
     ve_prov = QString();
     vucc_grids = QString();
@@ -276,12 +281,16 @@ int QSO::getLogId()
     return logId;
 }
 
-double QSO::setFreqTX(const double _f)
+bool QSO::setFreq(const double _f)
 {
+   //qDebug() << Q_FUNC_INFO << ": " << QString::number(_f);
     if (_f>0)
     {
         freq_tx = _f;
-        emit getBandSignal (freq_tx);
+       //qDebug() << Q_FUNC_INFO << ":-2 " << QString::number(freq_tx);
+        setBandFromFreq(freq_tx);
+        if (freq_rx<=0)
+            setFreqRX(freq_tx);
         return true;
     }
     else {
@@ -294,6 +303,7 @@ bool QSO::setFreqRX(const double _f)
     if (_f>0)
     {
         freq_rx = _f;
+        setBandFromFreq(_f, false);
         return true;
     }
     else {
@@ -352,9 +362,22 @@ bool QSO::setCall(const QString &_c)
 
 QString QSO::getCall()
 {
+    //qDebug() << Q_FUNC_INFO << ": " << callsign;
     return callsign;
 }
 
+void QSO::setBandFromFreq(const double _fr, bool TX)
+{
+    if (TX)
+    {
+        setBand (getBandNameFromFreq (_fr));
+    }
+    else
+    {
+       setBandRX (getBandNameFromFreq (_fr));
+    }
+}
+
 bool QSO::setBand(const QString &_c)
 {
     //qDebug() << Q_FUNC_INFO << ": " << _c;
@@ -362,6 +385,8 @@ bool QSO::setBand(const QString &_c)
     {
         band = _c;
         haveBand = true;
+        if (band_rx.isNull())
+            band_rx = band;
         return true;
     }
     else
@@ -1066,15 +1091,10 @@ double QSO::getRXPwr()
 // Comment Tab
 bool QSO::setComment(const QString &_c)
 {
-    if (!_c.isNull ())
-    {
-        comment = _c;
-        return true;
-    }
-    else
-    {
+    if (_c.isNull ())
         return false;
-    }
+    comment = _c;
+    return true;
 }
 
 QString QSO::getComment()
@@ -1112,27 +1132,28 @@ bool QSO::setPropMode(const QString &_c)
     //qDebug() << Q_FUNC_INFO << _c;
     if (!util->isValidPropMode (_c))
     {
+        //qDebug() << Q_FUNC_INFO << " - Not valid!";
         propMode = QString();
         return false;
     }
+    //qDebug() << Q_FUNC_INFO << " - OK END";
     propMode = _c;
     return true;
 }
 
 QString QSO::getPropMode()
 {
+    //qDebug() << Q_FUNC_INFO << ": " << propMode;
     return propMode;
 }
 
-
 bool QSO::setSOTA_REF(const QString &_c)
-{
-    if (_c.length ()>1)
-    {
-        sota_ref = _c;
-        return true;
-    }
-    return false;
+{// TODO: Check if the SOTA REF is Valid
+
+    if (_c.length ()<=1)
+        return false;
+    sota_ref = _c;
+    return true;
 }
 
 QString QSO::getSOTA_REF()
@@ -1194,12 +1215,11 @@ QString QSO::getMyRig()
 
 bool QSO::setMyAntenna(const QString &_c)
 {
-    if (_c.length ()>1)
-    {
-        my_antenna = _c;
-        return true;
-    }
-    return false;
+    if (_c.length ()<1)
+        return false;
+    my_antenna = _c;
+    return true;
+
 }
 
 QString QSO::getMyAntenna()
@@ -1329,7 +1349,6 @@ bool QSO::setStationCallsign(const QString &_c)
         return false;
     }
 
-
     //qDebug() << Q_FUNC_INFO << " - 010";
     if (util->isValidCall(aux))
     {
@@ -1388,7 +1407,7 @@ bool QSO::setSatName(const QString &_c)
     if (_c.length()>0)
     {
         satName = _c;
-        return true;
+        return setPropMode("SAT");
     }
     else
     {
@@ -1451,12 +1470,20 @@ int QSO::getA_Index()
 
 bool QSO::setAnt_az(const double _c)
 { //TODO: Adjust number: http://www.adif.org/312/ADIF_312.htm#QSO_Field_ANT_AZ
+    ant_az = fmod(_c, 360.0);
+    return true;
+    /*
     if ((0 <= _c) && (_c <= 360))
     {
-        ant_az = _c;
+        //ant_az = _c;
+
         return true;
     }
-    return false;
+    else
+    {
+
+    }
+    return false;*/
 }
 double QSO::getAnt_az()
 {
@@ -1480,7 +1507,7 @@ double QSO::getAnt_el()
 
 bool QSO::setAnt_Path(const QString &_c)
 {
-    if (!util->isValidAntPath (_c))
+    if (!adif->isValidAntPath (_c))
         return false;
     ant_path = _c;
     return true;
@@ -1593,8 +1620,9 @@ QString QSO::getOwnerCallsign()
 bool QSO::setEQ_Call(const QString &_c)
 {
     if (util->isValidCall(_c))
-    {contacted_owner = _c;
-       return true;
+    {
+        contacted_owner = _c;
+        return true;
     }
     else {
        return false;
@@ -1744,7 +1772,7 @@ QString QSO::getContestID()
 
 bool QSO::setCQZone(const int _i)
 {
-    if ((_i>=0) && (_i<=40))
+    if ((_i>0) && (_i<=40))
     {
         cqz = _i;
         return true;
@@ -1795,8 +1823,12 @@ QString QSO::getDarcDok()
 
 bool QSO::setEmail(const QString &_c)
 {
-    email = _c;
-    return true;
+    if (util->isValidEmail(_c))
+    {
+        email = _c;
+        return true;
+    }
+    return false;
 }
 
 QString QSO::getEmail()
@@ -1806,7 +1838,7 @@ QString QSO::getEmail()
 
 bool QSO::setFists(const int _i)
 {
-    if (_i>=0)
+    if (adif->isValidFISTS(QString::number(_i)))
     {
         fists = _i;
         return true;
@@ -1871,7 +1903,7 @@ int QSO::getIotaID()
 
 bool QSO::setItuZone(const int _i)
 {
-    if (_i>=0 && (_i<=90))
+    if (_i>0 && (_i<=90))
     {
         itu_zone = _i;
         return true;
@@ -1975,8 +2007,11 @@ QString QSO::getMsShower()
 }
 
 bool QSO::setQSOComplete(const QString &_c)
-{
-    qso_complete = _c;
+{ // Y, N, I, ? are the valid chars.
+  // Here we store the short version just for the DB
+  // If we need to export it to ADIF, we need to call util->getADIFQSO_CompleteFromDB()
+    qso_complete = util->getQSO_CompleteFromADIF(_c);
+    //qDebug() << Q_FUNC_INFO << ": " << qso_complete;
     return true;
 }
 
@@ -2439,6 +2474,8 @@ QString QSO::getState()
 bool QSO::setSubmode(const QString &_c)
 {
     submode = _c;
+    haveSubMode = true;
+
     //if (requestMode){
     //    emit getModeSignal(submode);
     //}
@@ -2536,12 +2573,12 @@ QString QSO::getMyWwffRef()
 
 
 // helper functions for hash, returns original function but takes string data as imput
-bool QSO::setAge(const QString &data) { return setAge(data.toInt()); }
+bool QSO::setAge(const QString &data) { return setAge(data.toDouble()); }
 bool QSO::setA_Index(const QString& data) { return setA_Index(data.toInt()); }
-bool QSO::setAnt_az(const QString& data) { return setAnt_az(data.toInt()); }
-bool QSO::setAnt_el(const QString& data) { return setAnt_el(data.toInt()); }
+bool QSO::setAnt_az(const QString& data) { return setAnt_az(data.toDouble()); }
+bool QSO::setAnt_el(const QString& data) { return setAnt_el(data.toDouble()); }
 bool QSO::setCQZone(const QString& data) { return setCQZone(data.toInt()); }
-bool QSO::setDistance(const QString& data) { return setDistance(data.toInt()); }
+bool QSO::setDistance(const QString& data) { return setDistance(data.toDouble()); }
 bool QSO::setDXCC(const QString& data) { return setDXCC(data.toInt()); }
 bool QSO::setFists(const QString& data) { return setFists(data.toInt()); }
 bool QSO::setFistsCC(const QString& data) { return setFistsCC(data.toInt()); }
@@ -2562,7 +2599,7 @@ bool QSO::setStx(const QString& data) { return setStx(data.toInt()); }
 bool QSO::setTenTen(const QString& data) { return setTenTen(data.toInt()); }
 bool QSO::setUksmg(const QString& data) { return setUksmg(data.toInt()); }
 
-bool QSO::setFreqTX(const QString& data) { return setFreqTX(data.toDouble()); }
+bool QSO::setFreq(const QString& data) { return setFreq(data.toDouble()); }
 bool QSO::setFreqRX(const QString& data) { return setFreqRX(data.toDouble()); }
 bool QSO::setRXPwr(const QString& data){ return setRXPwr(data.toDouble()); }
 bool QSO::setTXPwr(const QString& data){ return setTXPwr(data.toDouble()); }
@@ -2579,7 +2616,7 @@ bool QSO::setQSLRDate(const QString& data) { return setQSLRDate(util->getDateFro
 bool QSO::setQSLSDate(const QString& data) { return setQSLSDate(util->getDateFromADIFDateString(data)); }
 bool QSO::setDate(const QString& data) { return setDate(util->getDateFromADIFDateString(data)); }
 bool QSO::setDateOff(const QString& data) { return setDateOff(util->getDateFromADIFDateString(data)); }
-bool QSO::setQSORandom(const QString& data) { return setQSORandom(util->QStringToBool(data)); }
+bool QSO::setQSORandom(const QString& data) {  return setQSORandom(util->QStringToBool(data)); }
 bool QSO::setSilentKey(const QString& data) { return setSilentKey(util->QStringToBool(data)); }
 bool QSO::setSwl(const QString& data) { return setSwl(util->QStringToBool(data)); }
 bool QSO::setTimeOff(const QString& data) { return setTimeOff(util->getTimeFromADIFTimeString(data)); }
@@ -2639,7 +2676,7 @@ void QSO::InitializeHash() {
         {"FISTS", decltype(std::mem_fn(&QSO::decltype_function))(&QSO::setFists)},
         {"FISTS_CC", decltype(std::mem_fn(&QSO::decltype_function))(&QSO::setFistsCC)},
         {"FORCE_INIT", decltype(std::mem_fn(&QSO::decltype_function))(&QSO::setForceInit)},
-        {"FREQ", decltype(std::mem_fn(&QSO::decltype_function))(&QSO::setFreqTX)},
+        {"FREQ", decltype(std::mem_fn(&QSO::decltype_function))(&QSO::setFreq)},
         {"FREQ_RX", decltype(std::mem_fn(&QSO::decltype_function))(&QSO::setFreqRX)},
         {"GRIDSQUARE", decltype(std::mem_fn(&QSO::decltype_function))(&QSO::setGridSquare)},
         {"HRDLOG_QSO_UPLOAD_DATE", decltype(std::mem_fn(&QSO::decltype_function))(&QSO::setHRDUpdateDate)},
@@ -2751,7 +2788,7 @@ void QSO::InitializeHash() {
 bool QSO::setData(const QString &_adifPair)
 {
     logEvent (Q_FUNC_INFO, "Start", Debug);
-    //qDebug() << Q_FUNC_INFO << ": " << _adifPair;
+   //qDebug() << Q_FUNC_INFO << ": " << _adifPair;
     QStringList d;
     d.clear();
     d << util->getValidADIFFieldAndData(_adifPair);
@@ -2760,7 +2797,7 @@ bool QSO::setData(const QString &_adifPair)
         logEvent (Q_FUNC_INFO, "END - ADIF not valid", Debug);
         return false;
     }
-    //qDebug() << Q_FUNC_INFO << ": " << d.at(0) << "/" << d.at(1);
+   //qDebug() << Q_FUNC_INFO << ": " << d.at(0) << "/" << d.at(1);
 
     QString field = d.at(0).toUpper();
     QString data = d.at(1);
@@ -2776,10 +2813,10 @@ bool QSO::setData(const QString &_adifPair)
     return true;
 }
 
-bool QSO::toDB(int _qsoId)
+int QSO::toDB(int _qsoId)
 { // This function will add or modify a QSO in the DB depending on the _qsoID.
   // if _qsoID is >0 it should be an existing QSO in the DB.
-   //qDebug() << Q_FUNC_INFO << " - Start: qsoId: " << QString::number(_qsoId) ;
+    //qDebug() << Q_FUNC_INFO << " - Start: qsoId: " << QString::number(_qsoId) ;
     if (!isComplete ())
     {
         //qDebug() << Q_FUNC_INFO << " - QSO NOT COMPLETE";
@@ -2787,6 +2824,7 @@ bool QSO::toDB(int _qsoId)
     }
     //qDebug() << Q_FUNC_INFO << " - QSO Complete... adding";
     QString queryString;
+    queryString.clear();
     if (_qsoId<=0)
     {
         //qDebug() << Q_FUNC_INFO << " - qsoID <=0";
@@ -2806,14 +2844,20 @@ bool QSO::toDB(int _qsoId)
     //qDebug() << Q_FUNC_INFO << " - executing query";
     if (query.exec())
     {
-        //qDebug() << Q_FUNC_INFO << ": QSO ADDED/Modified: " << query.lastQuery ();
-        return true;
+        //qDebug() << Q_FUNC_INFO << QString(": QSO ADDED/Modified: %1 - %2").arg(callsign).arg(getDateTimeOn().toString("yyyyMMdd-hhmm"));
+       //qDebug() << Q_FUNC_INFO << ": QSO ADDED/Modified: " << query.lastQuery ();
+        return 1;//db->getLastInsertedQSO();
     }
     else
     {
+        //qDebug() << Q_FUNC_INFO << QString(": QSO NOT ADDED/Modified: %1 - %2").arg(callsign).arg(_qsoId);
+        //qDebug() << Q_FUNC_INFO << ": QSO NOT ADDED/Modified: " << query.lastQuery ();
+        //qDebug() << Q_FUNC_INFO << ": Error: " << query.lastError().databaseText();
+        //qDebug() << Q_FUNC_INFO << ": Error: " << query.lastError().nativeErrorCode();
         emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
-        return false;
+        return -2;
     }
+    query.finish();
 }
 
 QString QSO::getAddQueryString()
@@ -2838,7 +2882,7 @@ QString QSO::getAddQueryString()
         ":qso_date, :call, :rst_sent, :rst_rcvd, :bandid, :modeid, :cqz, :ituz, :dxcc, :address, :age, :cnty, :comment, :a_index, :ant_az, :ant_el, "
         ":ant_path, :arrl_sect, :award_submitted, :award_granted, :band_rx, :checkcontest, :class, :clublog_qso_upload_date, :clublog_qso_upload_status, :cont, "
         ":contacted_op, :contest_id, :country, :credit_submitted, :credit_granted, :darc_dok, :distance, :email, :eq_call, :eqsl_qslrdate, :eqsl_qslsdate, "
-        ":eqsl_qsl_rcvd, :eqsl_qsl_sent, :fists, :fists_cc, :force_init, :freq, :freq_rx, :gridsquare, :hrdlog_qso_upload_date, "
+        ":eqsl_qsl_rcvd, :eqsl_qsl_sent, :fists, :fists_cc, :force_init, :freq_tx, :freq_rx, :gridsquare, :hrdlog_qso_upload_date, "
         ":hrdlog_qso_upload_status, "
         ":iota, :iota_island_id, :k_index, :lat, :lon, :lotw_qslrdate, :lotw_qslsdate, :lotw_qsl_rcvd, :lotw_qsl_sent, :max_bursts, :ms_shower, "
         ":my_antenna, :my_city, :my_cnty, :my_country, :my_cq_zone, :my_dxcc, :my_fists, :my_gridsquare, :my_iota, :my_iota_island_id, :my_itu_zone, :my_lat, "
@@ -2863,7 +2907,7 @@ QString QSO::getModifyQueryString()
                    "credit_submitted = :credit_submitted, credit_granted = :credit_granted, darc_dok = :darc_dok, "
                    "distance = :distance, email = :email, eq_call = :eq_call, eqsl_qslrdate = :eqsl_qslrdate, "
                    "eqsl_qslsdate = :eqsl_qslsdate, eqsl_qsl_rcvd = :eqsl_qsl_rcvd, eqsl_qsl_sent = :eqsl_qsl_sent, "
-                   "fists = :fists, fists_cc = :fists_cc, force_init = :force_init, freq = :freq, freq_rx = :freq_rx, "
+                   "fists = :fists, fists_cc = :fists_cc, force_init = :force_init, freq = :freq_tx, freq_rx = :freq_rx, "
                    "gridsquare = :gridsquare, hrdlog_qso_upload_date = :hrdlog_qso_upload_date, "
                    "hrdlog_qso_upload_status = :hrdlog_qso_upload_status, iota = :iota, iota_island_id = :iota_island_id, "
                    "k_index = :k_index, lat = :lat, lon = :lon, lotw_qslrdate = :lotw_qslrdate, lotw_qslsdate = :lotw_qslsdate, "
@@ -2935,16 +2979,30 @@ int QSO::getBandIdFromBandName(bool _rxBand)
 
 int QSO::getModeIdFromModeName()
 {
-    // submode is not used, keep it empty.
-    // mode field is populated with the submode
+    // We need to save always the submode id
+    // If submode is no present, then we will store the mode id
    //qDebug() << Q_FUNC_INFO;
     QSqlQuery query;
     //
     // SELECT mode.id FROM mode WHERE mode.submode="FT4"
     // SELECT mode.id FROM mode WHERE mode.name="MFSK"
     bool ok = query.prepare ("SELECT mode.id FROM mode WHERE mode.submode=:submode");
-    //bool ok = query.prepare ("SELECT id from mode WHERE CASE WHEN ''<>:submode THEN submode=:submode ELSE name = :name END");
-    query.bindValue (":submode", getMode ());
+    if (!ok)
+    {
+        return -1;
+    }
+    if (haveSubMode)
+    {
+        query.bindValue (":submode", getSubmode ());
+    }
+    else if (haveMode)
+    {
+        query.bindValue (":submode", getMode ());
+    }
+    else
+    {
+        return -1;
+    }
 
     if (query.exec ())
     {
@@ -2956,20 +3014,20 @@ int QSO::getModeIdFromModeName()
             }
             else
             {
-               //qDebug() << Q_FUNC_INFO << " - Query NOT Valid";
+                return -4;
             }
         }
         else
         {
-           //qDebug() << Q_FUNC_INFO << " - Query NOT Next";
+            return -5;
         }
     }
     else
     {
         emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
-        return -1;
+        return -2;
     }
-    return -1;
+    return -3;
 }
 
 QSqlQuery QSO::getPreparedQuery(const QString &_s)
@@ -3033,7 +3091,7 @@ QSqlQuery QSO::getPreparedQuery(const QString &_s)
     query.bindValue(":fists_cc", getFistsCC ());
 
     query.bindValue(":force_init", util->boolToCharToSQLite (getForceInit()));
-    query.bindValue(":freq", getFreqTX());
+    query.bindValue(":freq_tx", getFreqTX());
     query.bindValue(":freq_rx", getFreqRX());
     query.bindValue(":gridsquare", getGridSquare());
     query.bindValue(":hrdlog_qso_upload_date", getHRDUpdateDate ());
@@ -3100,7 +3158,7 @@ QSqlQuery QSO::getPreparedQuery(const QString &_s)
     query.bindValue(":qsl_sent_via", getQSLSentVia());
     query.bindValue(":qsl_via", getQSLVia());
     query.bindValue(":qso_complete", getQSOComplete());
-    query.bindValue(":qso_random", getQSORandom());
+    query.bindValue(":qso_random", util->boolToCharToSQLite (getQSORandom()));
     query.bindValue(":qth", getQTH());
     query.bindValue(":region", getRegion ());
     query.bindValue(":rig", getRig ());
@@ -3122,9 +3180,9 @@ QSqlQuery QSO::getPreparedQuery(const QString &_s)
     query.bindValue(":stx", getStx());
     query.bindValue(":state", getState());
     query.bindValue(":station_callsign", getStationCallsign());
-    //query.bindValue(":submode", getModeIdFromModeName (true));
+    //query.bindValue(":submode", getModeIdFromModeName ());
 
-    query.bindValue(":swl", getSwl());
+    query.bindValue(":swl", util->boolToCharToSQLite (getSwl()));
     query.bindValue(":uksmg", getUksmg ());
     query.bindValue(":usaca_counties", getUsacaCounties ());
     query.bindValue(":ve_prov", getVeProv ());
@@ -3140,12 +3198,269 @@ QSqlQuery QSO::getPreparedQuery(const QString &_s)
 
 QString QSO::getADIF()
 {
+    if (!isComplete())
+        return QString();
     adif = new Adif(Q_FUNC_INFO);
 
     QString adifStr = QString();
     adifStr.append(adif->getADIFField ("CALL", callsign));
+    if (!qso_dateTime.isValid())
+        return QString();
     adifStr.append(adif->getADIFField ("QSO_DATE",  util->getADIFDateFromQDateTime(qso_dateTime)));
+    adifStr.append(adif->getADIFField ("QSO_DATE_OFF",  util->getADIFDateFromQDate(qso_date_off)));
     adifStr.append(adif->getADIFField ("TIME_ON",  util->getADIFTimeFromQDateTime(qso_dateTime)));
+    adifStr.append(adif->getADIFField ("TIME_OFF",  util->getADIFTimeFromQTime(qso_time_off)));
+    adifStr.append(adif->getADIFField ("RST_RCVD", RST_rx));
+    adifStr.append(adif->getADIFField ("RST_SENT",  RST_tx));
+    adifStr.append(adif->getADIFField ("BAND",  band));
+    if (QString::compare(band, band_rx) != 0)
+        adifStr.append(adif->getADIFField ("BAND_RX",  band_rx));
+    adifStr.append(adif->getADIFField ("MODE",  mode));
+    if (QString::compare(mode, submode) != 0)
+    adifStr.append(adif->getADIFField ("SUBMODE", submode ));
 
-    return adifStr;
+    if (adif->isValidCQz(QString::number(cqz)))
+        adifStr.append(adif->getADIFField ("CQZ",  QString::number(cqz) ));
+
+    if (adif->isValidITUz(QString::number(itu_zone)))
+        adifStr.append(adif->getADIFField ("ITUZ", QString::number(itu_zone) ));
+
+    if (adif->isValidDXCC(QString::number(dxcc)) && (dxcc>0))
+        adifStr.append(adif->getADIFField ("DXCC",  QString::number(dxcc)));
+    adifStr.append(adif->getADIFField ("ADDRESS",  address));
+    if (age>0.0)  //Only relevant if Age >0
+    adifStr.append(adif->getADIFField ("AGE",  QString::number(age)));
+    adifStr.append(adif->getADIFField ("CNTY",  county));
+    adifStr.append(adif->getADIFField ("COMMENT",  comment));
+    if ((adif->isValidA_Index(QString::number(a_index))) && (a_index>0))
+        adifStr.append(adif->getADIFField ("A_INDEX",  QString::number(a_index)));
+    if ((adif->isValidAnt_AZ(QString::number(ant_az))) && (ant_az!=0))
+        adifStr.append(adif->getADIFField ("ANT_AZ",  QString::number(ant_az)));
+    if ((adif->isValidAnt_EL(QString::number(ant_el))) && (ant_el!=0.0) )
+        adifStr.append(adif->getADIFField ("ANT_EL",  QString::number(ant_el)));
+    adifStr.append(adif->getADIFField ("ANT_PATH", ant_path));
+    adifStr.append(adif->getADIFField ("ARRL_SECT", arrl_sect ));
+    adifStr.append(adif->getADIFField ("AWARD_SUBMITTED",  award_submitted));
+    adifStr.append(adif->getADIFField ("AWARD_GRANTED",  award_granted));
+
+    adifStr.append(adif->getADIFField ("checkcontest",  check));
+    adifStr.append(adif->getADIFField ("class",  clase));
+    adifStr.append(adif->getADIFField ("clublog_qso_upload_status", clublog_status ));
+
+    if ((clublogDate.isValid()) && ((clublog_status =="Y") || (clublog_status =="N")))
+        adifStr.append(adif->getADIFField ("clublog_qso_upload_date",  util->getADIFDateFromQDate(clublogQSOUpdateDate) ));
+
+    adifStr.append(adif->getADIFField ("cont",  continent));
+    adifStr.append(adif->getADIFField ("contacted_op", contacted_op));
+    adifStr.append(adif->getADIFField ("contest_id",  contest_id));
+    adifStr.append(adif->getADIFField ("country",  country));
+    adifStr.append(adif->getADIFField ("credit_submitted",  credit_submitted));
+    adifStr.append(adif->getADIFField ("credit_granted", credit_granted ));
+
+    if (distance>0)
+        adifStr.append(adif->getADIFField ("darc_dok", QString::number(distance) ));
+    adifStr.append(adif->getADIFField ("email",  email));
+    adifStr.append(adif->getADIFField ("eq_call",  getEQ_Call()));
+
+    adifStr.append(adif->getADIFField ("eqsl_qsl_rcvd", eqsl_qsl_rcvd));
+    if (eQSLRDate.isValid())
+        adifStr.append(adif->getADIFField ("eqsl_qslrdate", util->getADIFDateFromQDate(eQSLRDate) ));
+
+    adifStr.append(adif->getADIFField ("eqsl_qsl_sent", eqsl_qsl_sent));
+    if (eQSLSDate.isValid())
+        adifStr.append(adif->getADIFField ("eqsl_qslsdate", util->getADIFDateFromQDate(eQSLSDate) ));
+
+    if (fists>0)
+        adifStr.append(adif->getADIFField ("fists", QString::number(fists)));
+
+    if (fists_cc>0)
+        adifStr.append(adif->getADIFField ("fists_cc", QString::number(fists_cc)));
+    if (forceInit)      // Only relevant if true
+        adifStr.append(adif->getADIFField ("force_init", adif->getADIFBoolFromBool(getForceInit()) ));
+
+    //qDebug() << Q_FUNC_INFO << ": Printing FREQ: " << QString::number(freq_tx);
+    if (adif->isValidFreq(QString::number(freq_tx)))
+        adifStr.append(adif->getADIFField ("freq",  QString::number(freq_tx)));
+
+    //qDebug() << Q_FUNC_INFO << ": Printing FREQ_RX";
+    if ((adif->isValidFreq(QString::number(freq_rx))) && (freq_tx != freq_rx))
+        adifStr.append(adif->getADIFField ("freq_rx", QString::number(freq_rx) ));
+
+    adifStr.append(adif->getADIFField ("gridsquare",  gridsquare));
+    adifStr.append(adif->getADIFField ("hrdlog_qso_upload_date",  util->getADIFDateFromQDate(hrdlogUploadDate)));
+    adifStr.append(adif->getADIFField ("hrdlog_qso_upload_status", hrdlog_status ));
+    adifStr.append(adif->getADIFField ("iota", iota));
+
+    if (iota_ID>0)
+        adifStr.append(adif->getADIFField ("iota_island_id", QString::number(iota_ID)));
+
+    if ((adif->isValidK_Index(QString::number(k_index))) && (k_index>0))
+        adifStr.append(adif->getADIFField ("k_index", QString::number(k_index)));
+    adifStr.append(adif->getADIFField ("lat", latitude));
+    adifStr.append(adif->getADIFField ("lon", longitude));
+    adifStr.append(adif->getADIFField ("lotw_qslrdate", util->getADIFDateFromQDate(QSLLoTWRDate)));
+    adifStr.append(adif->getADIFField ("lotw_qslsdate", util->getADIFDateFromQDate(QSLLoTWSDate)));
+    adifStr.append(adif->getADIFField ("lotw_qsl_rcvd", lotw_qsl_rcvd));
+    adifStr.append(adif->getADIFField ("lotw_qsl_sent", lotw_qsl_sent));
+
+    if (adif->isValidNRBursts(QString::number(getMaxBursts())))
+        adifStr.append(adif->getADIFField ("max_bursts", QString::number(getMaxBursts()) ));
+
+    adifStr.append(adif->getADIFField ("ms_shower",  ms_shower));
+    adifStr.append(adif->getADIFField ("my_antenna", my_antenna));
+    adifStr.append(adif->getADIFField ("my_city", my_city));
+
+    adifStr.append(adif->getADIFField ("my_cnty", my_county));
+    adifStr.append(adif->getADIFField ("my_country", my_country));
+
+    if (adif->isValidCQz(QString::number(my_cqz)))
+        adifStr.append(adif->getADIFField ("my_cq_zone", QString::number(my_cqz)));
+
+    if (adif->isValidDXCC(QString::number(my_dxcc)) && (my_dxcc>0))
+        adifStr.append(adif->getADIFField ("my_dxcc", QString::number(my_dxcc) ));
+
+    if (adif->isValidFISTS(QString::number(my_fists)))
+        adifStr.append(adif->getADIFField ("my_fists", QString::number(my_fists) ));
+    adifStr.append(adif->getADIFField ("my_gridsquare", my_gridsquare ));
+    adifStr.append(adif->getADIFField ("my_iota", my_iota));
+    if (adif->isValidIOTA_islandID(QString::number(getMyIotaID())))
+        adifStr.append(adif->getADIFField ("my_iota_island_id", QString::number(getMyIotaID())));
+
+    if (adif->isValidITUz(QString::number(my_itu_zone)))
+        adifStr.append(adif->getADIFField ("my_itu_zone", QString::number(my_itu_zone)));
+
+    adifStr.append(adif->getADIFField ("my_lat", my_latitude));
+    adifStr.append(adif->getADIFField ("my_lon", my_longitude));
+    adifStr.append(adif->getADIFField ("my_name", my_name));
+
+    adifStr.append(adif->getADIFField ("my_postal_code", my_postal_code));
+    adifStr.append(adif->getADIFField ("my_rig", my_rig));
+    adifStr.append(adif->getADIFField ("my_sig", my_sig));
+    adifStr.append(adif->getADIFField ("my_sig_info", my_sig_info));
+
+    adifStr.append(adif->getADIFField ("my_sota_ref", my_sota_ref));
+    adifStr.append(adif->getADIFField ("my_state", my_state));
+    adifStr.append(adif->getADIFField ("my_street", my_street));
+    adifStr.append(adif->getADIFField ("my_usaca_counties", my_usaca_counties));
+
+    adifStr.append(adif->getADIFField ("my_vucc_grids", my_vucc_grids));
+    adifStr.append(adif->getADIFField ("name", name));
+    adifStr.append(adif->getADIFField ("notes", notes));
+    if (adif->isValidNRBursts(QString::number(nr_bursts)))
+        adifStr.append(adif->getADIFField ("nr_bursts", QString::number(nr_bursts)));
+    if (adif->isValidPings(QString::number(nr_pings)))
+        adifStr.append(adif->getADIFField ("nr_pings", QString::number(nr_pings)));
+    adifStr.append(adif->getADIFField ("operator", operatorCall));
+    adifStr.append(adif->getADIFField ("owner_callsign", ownerCall));
+    adifStr.append(adif->getADIFField ("pfx", prefix));
+
+    adifStr.append(adif->getADIFField ("precedence", precedence));
+    adifStr.append(adif->getADIFField ("prop_mode", propMode));
+    adifStr.append(adif->getADIFField ("public_key", public_key));
+    adifStr.append(adif->getADIFField ("qrzcom_qso_upload_date",  util->getADIFDateFromQDate(QRZComDate) ));
+    adifStr.append(adif->getADIFField ("qrzcom_qso_upload_status", QRZCom_status ));
+
+    adifStr.append(adif->getADIFField ("qslmsg", qslmsg));
+    adifStr.append(adif->getADIFField ("qsl_rcvd", getQSL_RCVD()));
+
+    if ((QSLRDate.isValid()) && ( (qsl_rcvd=="Y") || (qsl_rcvd=='I') || (qsl_rcvd=='R')))
+        adifStr.append(adif->getADIFField ("qslrdate", util->getADIFDateFromQDate(QSLRDate) ));
+
+    adifStr.append(adif->getADIFField ("qsl_sent", getQSL_SENT()));
+    if ((QSLSDate.isValid()) && ( (qsl_sent=="Y") || (qsl_sent=='Q') || (qsl_sent=='I')))
+        adifStr.append(adif->getADIFField ("qslsdate", util->getADIFDateFromQDate(QSLSDate)));
+
+
+    if ((getQSL_RCVD()=="Y") or (getQSL_RCVD()=="V")) // Valid cases to use qslrcvdVia
+        adifStr.append(adif->getADIFField ("qsl_rcvd_via", qslRecVia));
+
+     if (getQSL_SENT()=="Y")                // Valid case to use qslsentVia
+        adifStr.append(adif->getADIFField ("qsl_sent_via", qslSenVia));
+    adifStr.append(adif->getADIFField ("qsl_via", qslVia));
+    adifStr.append(adif->getADIFField ("qso_complete", util->getADIFQSO_CompleteFromDB(getQSOComplete())));
+
+    //TODO: Check wether it makes sense to use this field for ALL QSOs or just when it is not random.
+    if (getQSORandom())
+        adifStr.append(adif->getADIFField ("qso_random", adif->getADIFBoolFromBool(getQSORandom())));
+
+    adifStr.append(adif->getADIFField ("qth", qth));
+    adifStr.append(adif->getADIFField ("region", region));
+    adifStr.append(adif->getADIFField ("rig", rig));
+
+    if (adif->isValidPower(QString::number(pwr_rx)))
+        adifStr.append(adif->getADIFField ("rx_pwr", QString::number(pwr_rx)));
+    adifStr.append(adif->getADIFField ("sat_mode", getSatMode()));
+    adifStr.append(adif->getADIFField ("sat_name", getSatName()));
+
+    if ((adif->isValidSFI(QString::number(sfi))) && (sfi>0))
+        adifStr.append(adif->getADIFField ("sfi", QString::number(sfi)));
+    adifStr.append(adif->getADIFField ("sig", sig));
+    adifStr.append(adif->getADIFField ("sig_info", sig_info));
+    if (silent_key) //We only save if SK
+        adifStr.append(adif->getADIFField ("silent_key", adif->getADIFBoolFromBool(silent_key)));
+    adifStr.append(adif->getADIFField ("skcc", skcc));
+
+    adifStr.append(adif->getADIFField ("sota_ref", sota_ref));
+    adifStr.append(adif->getADIFField ("srx_string", srx_string));
+    if (adif->isValidSRX(QString::number(nr_bursts)))
+        adifStr.append(adif->getADIFField ("srx", QString::number(srx)));
+    adifStr.append(adif->getADIFField ("stx_string", stx_string));
+    if (adif->isValidSTX(QString::number(nr_bursts)))
+        adifStr.append(adif->getADIFField ("stx", QString::number(stx)));
+
+    adifStr.append(adif->getADIFField ("state", state));
+    adifStr.append(adif->getADIFField ("station_callsign", stationCallsign));
+    if (swl)    // We only print it if it is a SWL QSO
+        adifStr.append(adif->getADIFField ("swl", adif->getADIFBoolFromBool(swl)));
+    if (adif->isValidUKSMG(QString::number(uksmg)))
+        adifStr.append(adif->getADIFField ("uksmg", QString::number(uksmg)));
+
+    adifStr.append(adif->getADIFField ("usaca_counties", usaca_counties));
+    adifStr.append(adif->getADIFField ("ve_prov", ve_prov));
+    adifStr.append(adif->getADIFField ("vucc_grids", vucc_grids));
+
+    if (adif->isValidTenTen(QString::number(ten_ten)))
+        adifStr.append(adif->getADIFField ("ten_ten", QString::number(ten_ten)));
+    if (adif->isValidPower(QString::number(pwr_tx)))
+        adifStr.append(adif->getADIFField ("tx_pwr", QString::number(pwr_tx)));
+    adifStr.append(adif->getADIFField ("web", web));
+    if (adif->isValidLogId(QString::number(getLogId())))
+        adifStr.append(adif->getADIFField ("APP_KLOG_LOGN", QString::number(getLogId())));
+    //return  qso.getADIF() + "<EOR>\n";
+    return adifStr + "<EOR>\n";;
+}
+
+QString QSO::getBandNameFromFreq(const double _n)
+{
+    logEvent (Q_FUNC_INFO, "Start", Debug);
+    bool sqlOk = false;
+    QString queryString = QString("SELECT name FROM band WHERE lower <= '%1' and upper >= '%1'").arg(_n);
+
+    QSqlQuery query(queryString);
+    sqlOk = query.exec();
+
+    if (sqlOk)
+    {
+        query.next();
+        if (query.isValid())
+        {
+            QString b = (query.value(0)).toString();
+            query.finish();
+            logEvent (Q_FUNC_INFO, "END-1", Debug);
+            return b;
+        }
+        else
+        {
+            query.finish();
+            logEvent (Q_FUNC_INFO, "END-2", Debug);
+            return QString();
+        }
+    }
+    else
+    {
+        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
+        query.finish();
+        logEvent (Q_FUNC_INFO, "END-3", Debug);
+        return QString();
+    }
 }
