@@ -34,8 +34,9 @@
 //#include <QDebug>
 #include "utilities.h"
 #include "klogdefinitions.h"
-#include "database.h"
 #include "adif.h"
+#include "database.h"
+
 //#include <functional>
 
 class QSO : public QObject
@@ -83,16 +84,14 @@ public:
     bool setLogId(const int _i);
     int getLogId();
 
-
     bool setBandRX(const QString &_c);
     QString getBandRX();
 
-
     bool setRSTTX(const QString &_c);
     QString getRSTTX();
     bool setRSTRX(const QString &_c);
     QString getRSTRX();
-    double setFreqTX(const double _f);
+    bool setFreq(const double _f);
     bool setFreqRX(const double _f);
     double getFreqTX();
     double getFreqRX();
@@ -283,7 +282,7 @@ public:
     QString getLatitude();
     bool setLongitude(const QString &_c);
     QString getLongitude();
-    bool setQSOComplete(const QString &_c);
+    bool setQSOComplete(const QString &_c);         // Receives valid ADIF data (Y/N/NIL/?)
     QString getQSOComplete();
     bool setNrBursts(const int _i);
     int getNrBursts();
@@ -380,17 +379,17 @@ public:
     QString getWwffRef();
     bool setMyWwffRef(const QString &_c);
     QString getMyWwffRef();
-    bool toDB(int _qsoId = 0);
+    int toDB(int _qsoId = 0);
     //bool add();
     //bool modify(const int _qsoId);
     bool isComplete();
     QString getADIF();
+    QString getBandNameFromFreq(const double _n); // Should be push out of this class
 
 
 signals:
     void debugLog (QString _func, QString _msg, DebugLogLevel _level);
-    void getBandSignal (double fr);         // Request the band to be filed for a given frequency
-    void getModeSignal (QString submode);   // Request the mode to be filled for a given submode
+    void  getModeSignal (QString submode);   // Request the mode to be filled for a given submode
     void queryError(QString functionFailed, QString errorCodeS, QString nativeError, QString failedQuery); // To alert about any failed query execution
 
 private:
@@ -400,11 +399,13 @@ private:
     QSqlQuery getPreparedQuery(const QString &_s);
     int getBandIdFromBandName(bool _rxBand=false);   // if rxBand = true, it will chec the bandRX
     int getModeIdFromModeName();
+    void setBandFromFreq(const double _fr, bool TX = true);
+    DataBase *db;
 
 
     int qsoId, logId, dxcc, a_index, k_index, cqz, fists, fists_cc, my_fists, iota_ID, itu_zone, nr_bursts, max_bursts, nr_pings, my_cqz, my_itu_zone, my_dxcc, my_iota_ID, srx, stx, uksmg;
     int ten_ten, sfi;
-    double freq_tx, freq_rx, pwr_rx, pwr_tx, age, ant_el, ant_az, freq, distance;
+    double freq_tx, freq_rx, pwr_rx, pwr_tx, age, ant_el, ant_az, distance;
 
     QString satName, satMode, callsign, stationCallsign, operatorCall, propMode, band, band_rx, mode, gridsquare, my_gridsquare, qth, name, RST_tx, RST_rx;
     QString qsl_rcvd, qsl_sent, qslSenVia, qslRecVia, qslVia, check, clase;
@@ -425,7 +426,7 @@ private:
 
     bool backup, lotwUpdating, realTime, manualMode, silent_key;
     bool keepComment, keepOther, keepMyData, keepSat, modifying, isValidDistance, forceInit, qso_random, swl;
-    bool haveBand, haveMode, haveDateTime, haveCall;
+    bool haveBand, haveMode, haveSubMode, haveDateTime, haveCall;
 
     Utilities *util;
     Adif *adif;
@@ -463,7 +464,7 @@ private:
     bool setTenTen(const QString &data);
     bool setUksmg(const QString &data);
 
-    bool setFreqTX(const QString& data);
+    bool setFreq(const QString& data);
     bool setFreqRX(const QString& data);
     bool setRXPwr(const QString& data);
     bool setTXPwr(const QString& data);
