@@ -28,7 +28,7 @@
 
 SetupPageLogView::SetupPageLogView(DataProxy_SQLite *dp, QWidget *parent) : QWidget(parent)
 {
-       //qDebug() << "SetupPageLogView::SetupPageLogView"   << QT_ENDL;
+       //qDebug() << "SetupPageLogView::SetupPageLogView"  ;
     dataProxy = dp;
 
     fieldsListWidget = new QListWidget;
@@ -41,21 +41,31 @@ SetupPageLogView::SetupPageLogView(DataProxy_SQLite *dp, QWidget *parent) : QWid
     fieldsLabel->setText(tr("Fields"));
     fieldsLabel->setAlignment(Qt::AlignVCenter| Qt::AlignCenter);
 
-    addFields(dataProxy->getFields());
-
-
     fLayout->addWidget(fieldsLabel);
     fLayout->addWidget(fieldsListWidget);
 
     layout->addLayout(fLayout);
 
     setLayout(layout);
-       //qDebug() << "SetupPageLogView::SetupPageLogView - END"   << QT_ENDL;
+       //qDebug() << "SetupPageLogView::SetupPageLogView - END"  ;
 }
 
 SetupPageLogView::~SetupPageLogView()
 {}
 
+void SetupPageLogView::init()
+{
+    addFields(dataProxy->getFields());
+    if (fieldsListWidget->count ()<1)
+    {
+        QStringList aux;
+        aux.clear ();
+        aux << "qso_date" << "call" << "rst_sent" << "rst_rcvd" << "bandid" << "modeid" << "comment";
+        aux.removeDuplicates();
+        setActiveFields(aux);
+    }
+}
+
 void SetupPageLogView::addFields(QStringList _b)
 {
     fieldsListWidget->addItems(_b);
@@ -68,46 +78,49 @@ void SetupPageLogView::addFields(QStringList _b)
     }
 }
 
-QString SetupPageLogView::getFields()
+QStringList SetupPageLogView::getActiveFields()
 {
-       //qDebug() << "SetupPageLogView::getBands" << QT_ENDL;
-
-    QString b;
-    QListWidgetItem *it;
-
+    //qDebug() << Q_FUNC_INFO;
     if ( (fieldsListWidget->count()) < 1)
     {
-        return "";
+        return QStringList();
     }
+    QStringList _list;
+    _list.clear ();
+     QListWidgetItem *it;
+    //QString b = QString();
     for (int i = 0; i < fieldsListWidget->count(); i++)
     {
         it = fieldsListWidget->item(i);
         if (it->checkState() == Qt::Checked)
         {
-            b = b + it->text();
-            b = b + ", ";
+            _list.append (it->text ());
+            //b = b + it->text();
+            //b = b + ", ";
         }
     }
-    if (b.size()>=2)
-    {
-        b.chop(2);
-    }
-    return b;
+    //if (b.size()>=2)
+    //{
+    //    b.chop(2);
+    //}
+    //qDebug() << Q_FUNC_INFO << " : " << b;
+    return _list;
+    //return b.split(", ", Qt::SkipEmptyParts);
 }
 
-
 void SetupPageLogView::setActiveFields(QStringList q)
 {
-       //qDebug() << "SetupPageLogView::setActiveFields" << QT_ENDL;
-
+    //qDebug() << Q_FUNC_INFO << " - Start";
     if (q.isEmpty())
-    {return;}
+    {
+        //qDebug() << Q_FUNC_INFO << " - Empty list - END-0";
+        return;
+    }
 
-    //QString b;
     QListWidgetItem *it;
-
     if ( (fieldsListWidget->count()) < 1)
     {
+        //qDebug() << Q_FUNC_INFO << " - END-1";
         return;
     }
 
@@ -118,11 +131,37 @@ void SetupPageLogView::setActiveFields(QStringList q)
 
         for (int j=0;j<q.length();j++)
         {
+            //qDebug() << Q_FUNC_INFO << " - Checking: " << q.at(j);
             if (it->text() == q.at(j))
             {
+                //qDebug() << Q_FUNC_INFO << " - Adding: " << q.at(j);
                 it->setCheckState(Qt::Checked);
             }
         }
     }
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
+void SetupPageLogView::saveSettings()
+{
+    //qDebug() << Q_FUNC_INFO ;
+    Utilities util(Q_FUNC_INFO);
+    QSettings settings(util.getCfgFile (), QSettings::IniFormat);
+    //settings.beginGroup ("LogView");
+    settings.setValue ("LogViewFields", getActiveFields ());
+    //settings.endGroup ();
+}
+
+void SetupPageLogView::loadSettings()
+{
+
+    //qDebug() << Q_FUNC_INFO << " - Start";
+    Utilities util(Q_FUNC_INFO);
+    QSettings settings(util.getCfgFile (), QSettings::IniFormat);
+    QStringList aux;
+    aux.clear();
+    aux << dataProxy->filterValidFields(settings.value("LogViewFields").toStringList ());
+    aux.removeDuplicates();
+    setActiveFields(aux);
+    //qDebug() << Q_FUNC_INFO << " - END";
+}
