@@ -32,7 +32,8 @@
 
 SetupPageSubdivisionNew::SetupPageSubdivisionNew(DataProxy_SQLite *dp, QWidget *parent)
 {
-      //qDebug() << "SetupPageSubdivisionNew::SetupPageSubdivisionNew"   << QT_ENDL;
+      //qDebug() << "SetupPageSubdivisionNew::SetupPageSubdivisionNew"  ;
+    Q_UNUSED(parent);
     dataProxy = dp;
     editing = false;
     checking = false;
@@ -73,7 +74,7 @@ SetupPageSubdivisionNew::SetupPageSubdivisionNew(DataProxy_SQLite *dp, QWidget *
 
     okButton->setEnabled(false);
 
-       //qDebug() << "SetupPageSubdivisionNew::SetupPageSubdivisionNew - END"   << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::SetupPageSubdivisionNew - END"  ;
 }
 
 SetupPageSubdivisionNew::~SetupPageSubdivisionNew()
@@ -83,7 +84,7 @@ SetupPageSubdivisionNew::~SetupPageSubdivisionNew()
 
 void SetupPageSubdivisionNew::clear()
 {
-      //qDebug() << "SetupPageSubdivisionNew::Clear - Start"   << QT_ENDL;
+      //qDebug() << "SetupPageSubdivisionNew::Clear - Start"  ;
     stationCallsignLineEdit->clear();
     operatorsLineEdit->clear();
     dateEdit->setDate(QDate::currentDate ());
@@ -106,12 +107,12 @@ void SetupPageSubdivisionNew::clear()
     contestBands = 0;
     contestCatOverlay = 0;
     typeContestSelected = 0;*/
-      //qDebug() << "SetupPageSubdivisionNew::Clear - END"   << QT_ENDL;
+      //qDebug() << "SetupPageSubdivisionNew::Clear - END"  ;
 }
 
 void SetupPageSubdivisionNew::createWidget()
 {
-      //qDebug() << "SetupPageSubdivisionNew::createWidget - Start" << QT_ENDL;
+      //qDebug() << "SetupPageSubdivisionNew::createWidget - Start";
 
     stationCallsignLabel->setWordWrap(true);
     operatorsLabel->setWordWrap(true);
@@ -152,7 +153,7 @@ void SetupPageSubdivisionNew::createWidget()
     _qs.clear();
     _qs.append(dataProxy->getContestNames());
     typeComboBox->addItems(_qs);
-       //qDebug() << "SetupPageSubdivisionNew::createWidget - contestNames: " << _qs.at(0) << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::createWidget - contestNames: " << _qs.at(0);
 
     catModeLabel->setText(tr("&Mode Category"));
     catModeLabel->setWordWrap(true);
@@ -270,14 +271,14 @@ void SetupPageSubdivisionNew::createWidget()
     setLayout(mainLayout);
     clear();
     //page->setLayout(callsLayout);
-      //qDebug() << "SetupPageSubdivisionNew::createWidget - End" << QT_ENDL;
+      //qDebug() << "SetupPageSubdivisionNew::createWidget - End";
 
 }
 
 
 void SetupPageSubdivisionNew::slotOperatorsTextChanged()
 {
-       //qDebug() << "SetupPageSubdivisionNew::slotOperatorsTextChanged - Start" << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::slotOperatorsTextChanged - Start";
 //    connect(stationCallsignLineEdit, SIGNAL(textChanged(QString)), this, SLOT( ) );
     if ((operatorsLineEdit->text()).length()<1)
     {
@@ -303,12 +304,12 @@ void SetupPageSubdivisionNew::slotOperatorsTextChanged()
     {//TODO: Add a check of the format (comma separated)
         operatorsFilled= true;
     }
-      //qDebug() << "SetupPageSubdivisionNew::slotOperatorsTextChanged - End" << QT_ENDL;
+      //qDebug() << "SetupPageSubdivisionNew::slotOperatorsTextChanged - End";
 }
 
 void SetupPageSubdivisionNew::slotStationCallSignTextChanged()
 {
-       //qDebug() << "SetupPageSubdivisionNew::slotStationCallSignTextChanged" << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::slotStationCallSignTextChanged";
 //    connect(stationCallsignLineEdit, SIGNAL(textChanged(QString)), this, SLOT( ) );
     if ((stationCallsignLineEdit->text()).length()<1)
     {
@@ -336,13 +337,13 @@ void SetupPageSubdivisionNew::slotStationCallSignTextChanged()
         stationCallsignFilled = true;
     }
     showOK();
-      //qDebug() << "SetupPageSubdivisionNew::slotStationCallSignTextChanged - End" << QT_ENDL;
+      //qDebug() << "SetupPageSubdivisionNew::slotStationCallSignTextChanged - End";
 }
 
 /*
 void SetupPageSubdivisionNew::slotTypeComboBoxChanged()
 {
-       //qDebug() << "SetupPageSubdivisionNew::slotTypeComboBoxChanged" << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::slotTypeComboBoxChanged";
 //    connect(typeComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotTypeComboBoxChanged() ) ) ;
 
 
@@ -372,7 +373,7 @@ void SetupPageSubdivisionNew::slotTypeComboBoxChanged()
 
 void SetupPageSubdivisionNew::slotCatAssistedComboBoxChanged()
 {
-      //qDebug() << "SetupPageLogs:slotCatAssistedComboBoxChanged: " << QString::number(contestCatAssistedComboBox->currentIndex())  << QT_ENDL;
+      //qDebug() << "SetupPageLogs:slotCatAssistedComboBoxChanged: " << QString::number(contestCatAssistedComboBox->currentIndex()) ;
 //connect(contestCatAssistedComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotCatAssistedComboBoxChanged() ) ) ;
 
    contestCatMode = contestCatModeComboBox->currentIndex();
@@ -400,7 +401,7 @@ void SetupPageSubdivisionNew::slotCatAssistedComboBoxChanged()
 
 void SetupPageSubdivisionNew::slotCatOperatorsComboBoxChanged()
 {
-      //qDebug() << "SetupPageSubdivisionNew::slotCatOperatorsComboBoxChanged(): " << QString::number(contestCatOperatorsComboBox->currentIndex())  << QT_ENDL;
+      //qDebug() << "SetupPageSubdivisionNew::slotCatOperatorsComboBoxChanged(): " << QString::number(contestCatOperatorsComboBox->currentIndex()) ;
 
    contestCatMode = contestCatModeComboBox->currentIndex();
    contestCatBands = contestCatBandsComboBox->currentIndex();
@@ -427,7 +428,7 @@ void SetupPageSubdivisionNew::slotCatOperatorsComboBoxChanged()
 
 void SetupPageSubdivisionNew::slotCatPowerComboBoxChanged()
 {
-       //qDebug() << "SetupPageSubdivisionNew::slotCatPowerComboBoxChanged(): " << QString::number(contestCatPowerComboBox->currentIndex())  << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::slotCatPowerComboBoxChanged(): " << QString::number(contestCatPowerComboBox->currentIndex()) ;
 //connect(contestCatPowerComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotCatPowerComboBoxChanged() ) ) ;
 
     contestCatMode = contestCatModeComboBox->currentIndex();
@@ -455,7 +456,7 @@ void SetupPageSubdivisionNew::slotCatPowerComboBoxChanged()
 
 void SetupPageSubdivisionNew::slotCatBandsComboBoxChanged()
 {
-       //qDebug() << "SetupPageSubdivisionNew::slotCatBandsComboBoxChanged(): " << QString::number(contestCatBandsComboBox->currentIndex())  << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::slotCatBandsComboBoxChanged(): " << QString::number(contestCatBandsComboBox->currentIndex()) ;
 //connect(contestCatBandsComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotCatBandsComboBoxChanged() ) ) ;
 
     contestCatMode = contestCatModeComboBox->currentIndex();
@@ -483,7 +484,7 @@ void SetupPageSubdivisionNew::slotCatBandsComboBoxChanged()
 
 void SetupPageSubdivisionNew::slotBandsComboBoxChanged()
 {
-       //qDebug() << "SetupPageSubdivisionNew::slotBandsComboBoxChanged(): " << QString::number(contestBandsComboBox->currentIndex()) << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::slotBandsComboBoxChanged(): " << QString::number(contestBandsComboBox->currentIndex());
             //connect(contestBandsComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotBandsComboBoxChanged() ) ) ;
 
 }
@@ -491,7 +492,7 @@ void SetupPageSubdivisionNew::slotBandsComboBoxChanged()
 
 void SetupPageSubdivisionNew::slotCatOverlayComboBoxChanged()
 {
-        //qDebug() << "SetupPageSubdivisionNew::slotCatOverlayComboBoxChanged(): " << QString::number(contestCatOverlayComboBox->currentIndex())  << QT_ENDL;
+        //qDebug() << "SetupPageSubdivisionNew::slotCatOverlayComboBoxChanged(): " << QString::number(contestCatOverlayComboBox->currentIndex()) ;
 
      contestCatMode = contestCatModeComboBox->currentIndex();
      contestCatBands = contestCatBandsComboBox->currentIndex();
@@ -502,7 +503,7 @@ void SetupPageSubdivisionNew::slotCatOverlayComboBoxChanged()
      contestCatOverlay= contestCatOverlayComboBox->currentIndex();
 
      typeContest = getSelectedTypeContest();
-        //qDebug() << "SetupPageSubdivisionNew::slotCatOverlayComboBoxChanged(): typeContest =  " << QString::number(typeContest)  << QT_ENDL;
+        //qDebug() << "SetupPageSubdivisionNew::slotCatOverlayComboBoxChanged(): typeContest =  " << QString::number(typeContest) ;
 
      if (typeContest < 0)
      {
@@ -519,7 +520,7 @@ void SetupPageSubdivisionNew::slotCatOverlayComboBoxChanged()
 
 void SetupPageSubdivisionNew::slotCatModeComboBoxChanged()
 {
-       //qDebug() << "SetupPageSubdivisionNew::slotCatModeComboBoxChanged(): " << QString::number(contestCatModeComboBox->currentIndex())  << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::slotCatModeComboBoxChanged(): " << QString::number(contestCatModeComboBox->currentIndex()) ;
 
     contestCatMode = contestCatModeComboBox->currentIndex();
     contestCatBands = contestCatBandsComboBox->currentIndex();
@@ -530,7 +531,7 @@ void SetupPageSubdivisionNew::slotCatModeComboBoxChanged()
     contestCatOverlay= contestCatOverlayComboBox->currentIndex();
 
     typeContest = getSelectedTypeContest();
-       //qDebug() << "SetupPageSubdivisionNew::slotCatModeComboBoxChanged(): " << QString::number(typeContest)  << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::slotCatModeComboBoxChanged(): " << QString::number(typeContest) ;
 
     if (typeContest < 0)
     {
@@ -548,7 +549,7 @@ void SetupPageSubdivisionNew::slotCatModeComboBoxChanged()
 void SetupPageSubdivisionNew::slotOKButtonClicked()
 {
 
-       //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked" << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked";
     stationCallsign = stationCallsignLineEdit->text();
     if (stationCallsign.length()<3)
     {
@@ -587,92 +588,92 @@ void SetupPageSubdivisionNew::slotOKButtonClicked()
 /*
     if (typeComboBox->isEnabled())
     {
-           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked ENA: type" << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked ENA: type";
         typeContestSelected = typeComboBox->currentIndex();
         typeConteststr = typeComboBox->currentText();
     }
     else
     {
-           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked NOT ENA: type" << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked NOT ENA: type";
         typeContestSelected = 0;
         typeConteststr = QString();
     }
 
     if (contestCatModeComboBox->isEnabled())
     {
-           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked ENA: mode" << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked ENA: mode";
         contestCatMode = contestCatModeComboBox->currentIndex();
     }
     else
     {
-           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked NOT ENA: mode" << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked NOT ENA: mode";
         contestCatMode = 0;
     }
 
     if (contestCatOperatorsComboBox->isEnabled())
     {
-           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked ENA: oper" << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked ENA: oper";
        contestCatOperators = contestCatOperatorsComboBox->currentIndex();
     }
     else
     {
-           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked NOT ENA: oper" << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked NOT ENA: oper";
         contestCatOperators = 0;
     }
 
     if (contestCatAssistedComboBox->isEnabled())
     {
-           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked ENA: ass" << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked ENA: ass";
         contestCatAssisted = contestCatAssistedComboBox->currentIndex();
     }
     else
     {
-           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked NOT ENA: ass" << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked NOT ENA: ass";
         contestCatAssisted = 0;
     }
 
     if (contestCatPowerComboBox->isEnabled())
     {
-           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked ENA: pwr" << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked ENA: pwr";
         contestCatPower = contestCatPowerComboBox->currentIndex();
-           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked ENA: pwr - " << contestCatPowerComboBox->currentText() << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked ENA: pwr - " << contestCatPowerComboBox->currentText();
     }
     else
     {
-           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked NOT ENA: pwr" << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked NOT ENA: pwr";
          contestCatPower = 0;
     }
 
     if (contestCatBandsComboBox->isEnabled())
     {
-           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked ENA: Cbands" << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked ENA: Cbands";
         contestCatBands = contestCatBandsComboBox->currentIndex();
     }
     else
     {
-           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked NOT ENA: Cbands" << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked NOT ENA: Cbands";
         contestCatBands = 0;
     }
 
     if (contestBandsComboBox->isEnabled())
     {
-           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked ENA: bands" << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked ENA: bands";
         contestBands = contestBandsComboBox->currentIndex();
     }
     else
     {
-           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked NOT ENA: bands" << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked NOT ENA: bands";
         contestBands = 0;
     }
 
     if (contestCatOverlayComboBox->isEnabled())
     {
-           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked ENA: over" << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked ENA: over";
         contestCatOverlay = contestCatOverlayComboBox->currentIndex();
     }
     else
     {
-           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked NOT ENA: over" << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::slotOkButtonClicked NOT ENA: over";
         contestCatOverlay = 0;
     }
 
@@ -698,7 +699,7 @@ void SetupPageSubdivisionNew::slotOKButtonClicked()
 
 void SetupPageSubdivisionNew::gatherAndSend()
 {
-        //qDebug() << "SetupPageSubdivisionNew::gatherAndSend: "  << QT_ENDL;
+        //qDebug() << "SetupPageSubdivisionNew::gatherAndSend: " ;
 
     // The following lines will be removed once more contest types have been added
     //contestCatMode = contestCatModeComboBox->currentIndex();
@@ -741,14 +742,14 @@ void SetupPageSubdivisionNew::gatherAndSend()
     //logData << QString::number(typeContest)
     // Update the SetupPageLogs::slotAnalyzeNewLogData if you add or remove any field (Today 12)
 
-       //qDebug() << "SetupPageSubdivisionNew::gatherAndSend: EMITED" << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::gatherAndSend: EMITED";
     emit newLogData(logData);
 
 }
 
 void SetupPageSubdivisionNew::slotCancelButtonClicked()
 {
-       //qDebug() << "SetupPageSubdivisionNew::slotCancelButtonClicked" << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::slotCancelButtonClicked";
     logData.clear();
     emit cancelled(true);
     setResult(QDialog::Rejected);
@@ -767,7 +768,7 @@ QStringList SetupPageSubdivisionNew::getValidCatOptions(const int _currentCat, c
 // 5 - contestcatoverlay
 // 6 - contestcatmode
 
-       //qDebug() << "SetupPageSubdivisionNew::getValidCatOptions: " << QString::number(_currentCat) <<"/"<< QString::number(_higherCat) << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::getValidCatOptions: " << QString::number(_currentCat) <<"/"<< QString::number(_higherCat);
     //return dataProxy->getValidCatOptions(_currentCat, _higherCat);
     return QStringList();
 }
@@ -864,32 +865,32 @@ void SetupPageSubdivisionNew::setEditing(const bool b)
 /*
 int SetupPageSubdivisionNew::getSelectedTypeContest()
 {
-       //qDebug() << "SetupPageSubdivisionNew::getSelectedTypeContest: " << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::getSelectedTypeContest: ";
     //is/contest/catoperator/catassisted/catpower/catband/catoverlay/catmode
     int i = dataProxy->getContestTypeN(typeContestSelected, contestCatOperators, contestCatAssisted, contestCatPower, contestCatBands, contestCatOverlay, contestCatMode);
-       //qDebug() << "SetupPageSubdivisionNew::getSelectedTypeContest: " << QString::number(i) << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::getSelectedTypeContest: " << QString::number(i);
     return i;
 
 }
 
 void SetupPageSubdivisionNew::setTypeN(const int _n)
 {
-       //qDebug() << "SetupPageSubdivisionNew::setTypeN: " << QString::number(_n) << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::setTypeN: " << QString::number(_n);
     typeContestSelected = _n;
     fillWithType(typeContestSelected);
 }
 
 void SetupPageSubdivisionNew::fillWithType(const int _n)
 {
-       //qDebug() << "SetupPageSubdivisionNew::fillWithType - n = " << QString::number(_n) << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::fillWithType - n = " << QString::number(_n);
     typeContestSelected = _n;
     QStringList contestData;
     contestData << dataProxy->getDataFromContestType(_n);
-       //qDebug() << "SetupPageSubdivisionNew::fillWithType-1 (length = " << QString::number(contestData.length()) << ")" << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::fillWithType-1 (length = " << QString::number(contestData.length()) << ")";
     if (contestData.length()== 8)
     {
 
-           //qDebug() << "SetupPageSubdivisionNew::fillWithType-2" << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::fillWithType-2";
         //setCOperators ((contestData.at(1)).toInt());
         //setCAssisted ((contestData.at(2)).toInt());
         //setCPower ((contestData.at(3)).toInt());
@@ -897,11 +898,11 @@ void SetupPageSubdivisionNew::fillWithType(const int _n)
         //setCMode ((contestData.at(5)).toInt());
         //setType(contestData.at(6));
         //setCBands((contestData.at(7)).toInt());
-           //qDebug() << "SetupPageSubdivisionNew::fillWithType: " << contestData.at(6) << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::fillWithType: " << contestData.at(6);
     }
     else
     {
-           //qDebug() << "SetupPageSubdivisionNew::fillWithType-3" << QT_ENDL;
+           //qDebug() << "SetupPageSubdivisionNew::fillWithType-3";
         return;
     }
 
@@ -910,7 +911,7 @@ void SetupPageSubdivisionNew::fillWithType(const int _n)
 
 void SetupPageSubdivisionNew::updateAllCats()
 {
-       //qDebug() << "SetupPageSubdivisionNew::updateAllCats" << QT_ENDL;
+       //qDebug() << "SetupPageSubdivisionNew::updateAllCats";
 
     contestCatMode = contestCatModeComboBox->currentIndex();
     contestCatBands = contestCatBandsComboBox->currentIndex();
