@@ -28,9 +28,11 @@
 //bool c;
 Utilities::Utilities(const QString &_parentName)
 {
+    //qDebug() << Q_FUNC_INFO << " - Start";
     parentName = _parentName;
     //qDebug() << Q_FUNC_INFO << " (" << _parentName << ")";
     init();
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 Utilities::~Utilities()
@@ -280,7 +282,7 @@ double Utilities::getVersionDouble()
 
 int Utilities::getProgresStepForDialog(int totalSteps)
 {
-       //qDebug() << "Utilities::getProgresStepForDialog";
+    //qDebug() << Q_FUNC_INFO << ": " << QString::number(totalSteps);
     if (totalSteps <=100)
         return 1;
     else if (totalSteps <=1000)
@@ -317,44 +319,32 @@ bool Utilities::trueOrFalse(const QString &_s)
 QChar Utilities::boolToCharToSQLite(const bool _b)
 {
     if (_b)
-    {
         return 'Y';
-    }
-    else
-    {
-        return 'N';
-    }
+    return 'N';
 }
 
+
 QString Utilities::boolToQString(const bool _b)
 {
     if (_b)
-    {
         return "True";
-    }
-    else
-    {
-        return "False";
-    }
+    return "False";
 }
 
 bool Utilities::QStringToBool(const QString &_s)
 {
-
-    if ( (_s.toUpper()) == "Y")
-    {
+   //qDebug() << Q_FUNC_INFO << ": " << _s;
+    if (_s.toUpper() == "Y")
         return true;
-    }
-    else
-    {
-        return false;
-    }
+    return false;
+    //return ((_s.toUpper()) == "Y");
 }
 
 QString Utilities::checkAndFixASCIIinADIF(const QString &_data)
 {
     //qDebug() << "SetupDialog::checkAndFixASCIIinADIF " << _data ;
-// This function is not really working with ASCII but with Unicode
+    //TODO This function should be moved to the class ADIF
+    // This function is not really working with ASCII but with Unicode
     ushort unicodeVal;
     QString st = _data;
     QString newString;
@@ -526,93 +516,31 @@ QString Utilities::getKLogDefaultDatabaseFile()
     return getHomeDir() ;
 }
 
+QString Utilities::getDBPath()
+{   //Returns the path (folder level) of the DB
+
+    QSettings settings(getCfgFile (), QSettings::IniFormat);
+    settings.beginGroup ("Misc");
+    QString dbPath = settings.value ("DBPath").toString ();
+
+    if (dbPath.length()<1)
+    {
+        dbPath = getKLogDefaultDatabaseFile();
+    }
+    return dbPath;
+}
+
 QString Utilities::getKLogDBFile()
-{
-        //qDebug() << "Utilities::getKLogDBFile: start " ;
-
-    dbPath = getKLogDefaultDatabaseFile();
-    QFile file(getCfgFile());
-
-    if (!file.open(QIODevice::ReadOnly | QIODevice::Text))  /* Flawfinder: ignore */
-    {
-        //return dbPath;
-        //return getKLogDatabaseFile(dbPath);
-    }
-    else
-    {
-        while (!file.atEnd()) {
-            QByteArray line = file.readLine();
-            processConfigLine(line);
-        }
-
-        if (dbPath.length()<1)
-        {
-            dbPath = getKLogDefaultDatabaseFile();
-        }
-    }
-       //qDebug() << "Utilities::getKLogDBFile: path to use: " << dbPath ;
-    return dbPath + "/logbook.dat";
+{   // Returns the full path to the main DB
+    return getDBPath() + "/logbook.dat";
 }
 
 QString Utilities::getKLogDBBackupFile()
-{
-        //qDebug() << "Utilities::getKLogDBFile: start " ;
-
-    dbPath = getKLogDefaultDatabaseFile();
-    QFile file(getCfgFile());
-
-    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) /* Flawfinder: ignore */
-    {
-        //return dbPath;
-        //return getKLogDatabaseFile(dbPath);
-    }
-    else
-    {
-        while (!file.atEnd()) {
-            QByteArray line = file.readLine();
-            processConfigLine(line);
-        }
-        if (dbPath.length()<1)
-        {
-            dbPath = getKLogDefaultDatabaseFile();
-        }
-    }
-       //qDebug() << "Utilities::getKLogDBFile: path to use: " << dbPath ;
-    return dbPath + "/" + QDateTime::currentDateTime().toString("yyyyMMdd-hhmmss") + "-backup-logbook.dat" ;
+{   // Returns the full path to the backup DB
+    return getDBPath() + "/" + QDateTime::currentDateTime().toString("yyyyMMdd-hhmmss") + "-backup-logbook.dat" ;
 }
 
-bool Utilities::processConfigLine(const QString &_line)
-{
-             //qDebug() << "Utilities::processConfigLine: " << _line ;
 
-        QString line = _line.simplified();
-        //line.simplified();
-        //QString aux;
-        QStringList values = line.split("=", QT_SKIP);
-
-        if (line.startsWith('#')){
-                 //qDebug() << "Utilities::processConfigLine: notes Line!" ;
-            return true;
-        }
-        if (!( (line.contains('=')) && (line.contains(';')))){
-                 //qDebug() << "Utilities::processConfigLine: Wrong Line!" ;
-            return false;
-        }
-        QString field = (values.at(0)).toUpper();
-        QString value = values.at(1);
-
-        int endValue = value.indexOf(';');
-        if (endValue>-1){
-            value = value.left(value.length() - (value.length() - endValue));
-        }
-
-        if (field == "DBPATH")
-        {
-                  //qDebug() << "Utilities::processConfigLine: dbPATH found: " << value ;
-            dbPath = value;
-        }
-        return true;
-}
 
 /*
 QString Utilities::getKLogDatabaseFile(const QString &_file)
@@ -1233,140 +1161,6 @@ QString Utilities::getPrefixFromCall(const QString &_c, bool withAreaNumber)
         i--;
     }
     return QString();
-    /*
-    QString call2 = call;
-    QString call3 = call;
-    bool keepAnalyzing  = true;
-    bool found = false;
-    bool secondCharIsNumber = false;
-
-    if ((call.at(1)).isDigit())
-    {
-        secondCharIsNumber = true;
-    }
-
-    //GW1A
-    while (keepAnalyzing)
-    {
-        //qDebug() << Q_FUNC_INFO << " - call: " << call;
-        //qDebug() << Q_FUNC_INFO << " - call2: " << call2;
-        //qDebug() << Q_FUNC_INFO << " - call3: " << call3;
-        if (isAKnownPrefix(call))
-        {
-            //qDebug() << Q_FUNC_INFO << ": Found!: " << call;
-            keepAnalyzing = false;
-            found = true;
-        }
-        else if (call.length()<=2)
-        {
-           //qDebug() << Q_FUNC_INFO << ": Not found & call<=2: " << call;
-           keepAnalyzing = false;
-        }
-        else
-        {
-            //qDebug() << Q_FUNC_INFO << ": else, chop: " << call;
-            call3 = call2;
-            call2 = call;
-            call.chop(1);
-        }
-    }
-
-    //qDebug() << Q_FUNC_INFO << ": **** Out of while: " << call << "/" << call2 << "/" << call3;
-    if (found)
-    {
-        //qDebug() << Q_FUNC_INFO << ": END-0 " << call;
-        return call;
-    }
-    else
-    {
-        if (firstSpecial)
-        {
-            call3 = call2;
-            call2 = call;
-            call.chop(1);
-        }
-        //qDebug() << Q_FUNC_INFO << ": **** Out of while Special 1-Letter: " << call << "/" << call2 << "/" << call3;
-    }
-
-    //qDebug() << Q_FUNC_INFO << ": **** To process: " << call << "/" << call2 << "/" << call3;
-    if (withAreaNumber)
-    {
-        //qDebug() << Q_FUNC_INFO << ": WithAreaNumber";
-        if (firstSpecial)
-        {
-            //qDebug() << Q_FUNC_INFO << ": FirstSpecial";
-            int last = call2.length();
-            //qDebug() << Q_FUNC_INFO << ": last="<< QString::number(last);
-            if (call.length()==1)
-            {
-                //qDebug() << Q_FUNC_INFO << ": END0: " << call;
-                return call;
-            }
-            else if (((call2.at(last-1)).isDigit()))
-            {//K1
-                //qDebug() << Q_FUNC_INFO << ": END1: " << call2;
-                return call2;
-            }
-            else if ((call3.at(call3.length()-1)).isDigit())
-            {//KB1
-                //qDebug() << Q_FUNC_INFO << ": END2: " << call3;
-                return call3;
-            }
-            else
-            {
-                //qDebug() << Q_FUNC_INFO << ": END3: " << call;
-                return call;
-            }
-        }
-        else
-        {
-            if (call == call2)
-            {
-                //qDebug() << Q_FUNC_INFO << ": END4: " << call;
-                return call;
-            }
-
-            int last = call2.length();
-            if (((call2.at(last-1)).isDigit()))
-            {
-                //qDebug() << Q_FUNC_INFO << ": END5: " << call2;
-                return call2;
-            }
-            //qDebug() << Q_FUNC_INFO << ": END6: " << call;
-            //return call;
-        }
-    }
-//Si se pide el numero pero el prefijo no trae numero se devuelve sin numero.
-    if (firstSpecial)
-    {
-        //qDebug() << Q_FUNC_INFO << ": call2: " << call2;
-        if (isAKnownPrefix(call2))
-        {
-            //qDebug() << Q_FUNC_INFO << ": END7.1: " << call;
-            return call2;
-        }
-        else if (!secondCharIsNumber && (call.at(3)).isDigit())
-        {
-            //qDebug() << Q_FUNC_INFO << ": END7.2: " << call;
-            return call;
-        }
-        //qDebug() << Q_FUNC_INFO << ": END7.3: " << call;
-        //return call;
-    }
-    int last = call2.length();
-    if (!((call2.at(last-1)).isDigit()))
-    {
-        if (isAKnownPrefix(call))
-        {
-            //qDebug() << Q_FUNC_INFO << ": END7.5: " << call2;
-            return call;
-        }
-        //qDebug() << Q_FUNC_INFO << ": END8: " << call2;
-        return call2;
-    }
-    //qDebug() << Q_FUNC_INFO << ": END9: " << call;
-    return call;
-    */
 }
 
 bool Utilities::isAOneLetterPrefix(const QChar &_c)
@@ -1576,12 +1370,6 @@ bool Utilities::isValidUpload_Status(const QString &c)
     return ((c == "Y") || (c == "N") || (c == "M"));
 }
 
-
-bool Utilities::isValidFISTS(const QString &c)
-{
-    return (c.toInt ()>0);
-}
-
 QStringList Utilities::getValidADIFFieldAndData(const QString &_b)
 {
    //qDebug() << "Utilities::getValidADIFFieldAndData: " << _b ;
@@ -1741,7 +1529,7 @@ bool Utilities::isValidDXCC(const int _d)
 }
 
 bool Utilities::isValidAntPath(const QString &_s)
-{
+{ // MOVE IT TO ADIF
    return ((_s == "G") || (_s == "O") || (_s == "S") || (_s == "L"));
 }
 
@@ -1820,14 +1608,7 @@ QDate Utilities::getDateFromLoTWQSLDateString(const QString &_s)
 
 QString Utilities::getADIFDateFromQDateTime(const QDateTime &_d)
 {
-    if (!_d.isValid())
-    {
-        return QString();
-    }
-    else
-    {
-        return _d.date().toString("yyyyMMdd");
-    }
+    return getADIFDateFromQDate(_d.date());
 }
 
 QString Utilities::getADIFDateFromQDate(const QDate &_d)
@@ -1843,6 +1624,11 @@ QString Utilities::getADIFDateFromQDate(const QDate &_d)
 }
 
 QString Utilities::getADIFTimeFromQDateTime(const QDateTime &_d)
+{
+    return getADIFTimeFromQTime(_d.time());
+}
+
+QString Utilities::getADIFTimeFromQTime(const QTime &_d)
 {
     if (!_d.isValid())
     {
@@ -1850,7 +1636,9 @@ QString Utilities::getADIFTimeFromQDateTime(const QDateTime &_d)
     }
     else
     {
-        return _d.time().toString("hhmmss");
+        if (_d.second() == 0)
+            return _d.toString("hhmm");
+        return _d.toString("hhmmss");
     }
 }
 
@@ -1879,6 +1667,64 @@ QString Utilities::getCabrilloTimeFromQDateTime(const QDateTime &_d)
     }
 }
 
+QString Utilities::getQSO_CompleteFromADIF(const QString &_s)
+{ // Receives a valid QSO_COMPLETE ADIF data and returns
+  // one char to be stored in the data base.
+  // Default value is Y
+    //Parece que falla al guardar este campo que no se traduce a un varchar(1)
+    //qDebug() << Q_FUNC_INFO << ": " << _s;
+
+    Adif adif(Q_FUNC_INFO);
+    if (!adif.isValidQSO_COMPLETE(_s))
+    {
+        //qDebug() << Q_FUNC_INFO << " No valid";
+        return "1";
+    }
+    if (_s == "N")
+    {
+       return "2";
+    }
+    else if (_s == "NIL")
+    {
+        return "3";
+    }
+    else if (_s == "?")
+    {
+        return "4";
+    }
+    else
+    {
+        return "1";
+    }
+}
+
+QString Utilities::getADIFQSO_CompleteFromDB(const QString &_s)
+{// Returns the ADIF QSO_COMPLETE
+    //1=Y, 2=N, 3=NIL, 4=?
+    //qDebug() << Q_FUNC_INFO << ": " << _s;
+    int i = _s.toInt();
+    switch (i)
+    {
+        case 2:
+        {
+            return "N";
+        }
+        case 3:
+        {
+            return "NIL";
+        }
+        case 4:
+        {
+            return "?";
+        }
+        default:
+        {
+            return "Y";
+        }
+    }
+}
+
+
 QString Utilities::getOnlineServiceName(OnLineProvider _service)
 {//enum OnLineProvider {ClubLog, LoTW, eQSL, QRZ}; //, HamQTH, HRDLog
     switch (_service)
@@ -2342,7 +2188,7 @@ bool Utilities::isValidContinent(const QString &_s)
 }
 
 bool Utilities::isValidPropMode(const QString &_s)
-{
+{ //TODO MOVE IT TO ADIF
     QStringList propModes;
     propModes.clear ();
     propModes << "AS" << "AUE" << "AUR" << "BS" << "ECH" << "EME" << "ES"
@@ -2351,9 +2197,19 @@ bool Utilities::isValidPropMode(const QString &_s)
     return propModes.contains (_s.toUpper ());
 }
 
+bool Utilities::isValidEmail(const QString &_s)
+{
+    QRegExp mailREX("\\b[A-Z0-9._%+-]+@[A-Z0-9.-]+\\.[A-Z]{2,4}\\b");
+    mailREX.setCaseSensitivity(Qt::CaseInsensitive);
+    mailREX.setPatternSyntax(QRegExp::RegExp);
+    return mailREX.exactMatch(_s);
+    //return ((_s.contains("@")) && (_s.contains(".")));
+}
+
+
 bool Utilities::isValidDistance(const double _d)
 {
-    return (_d>=0);
+    return (_d>0);
 }
 
 bool Utilities::isValidSponsor(const QString &_s)
