@@ -42,6 +42,7 @@
 #include <QtDebug>
 #include "locator.h"
 #include "klogdefinitions.h"
+#include "adif.h"
 //#include "dataproxy_sqlite.h"
 
 class Utilities : public QObject {
@@ -67,6 +68,7 @@ public:
     //QOperatingSystemVersion getOS();
     //Devel or debug functions - Not adding any feature to the user
     void printQString(const QStringList &_qs);
+
     QString getKLogDBFile();
     QString getKLogDBBackupFile();
     bool QStringToBool(const QString &_s);
@@ -115,7 +117,7 @@ public:
     bool isValidQSL_Rcvd(const QString &c);
     bool isValidQSL_Sent(const QString &c);
     bool isValidUpload_Status(const QString &c);
-    bool isValidFISTS(const QString &c);
+    //bool isValidFISTS(const QString &c);
 
     bool isValidTimeFromString(const QString &_s);
     bool isValidDateFromString(const QString &_s);
@@ -125,6 +127,7 @@ public:
     bool isValidARRLSect(const QString &_s);
     bool isValidContinent(const QString &_s);
     bool isValidPropMode(const QString &_s);
+    bool isValidEmail(const QString &_s);
     QStringList getValidADIFFieldAndData(const QString &_b);
     //QString getADIFField(const QString &_fieldName, const QString &_data);
 
@@ -145,10 +148,12 @@ public:
     // Translate the LOG table fields into human readable
     QString getLogColumnName(const QString &_column);
 
+
     // Creates the ADIF DATE & TIME formats
     QString getADIFDateFromQDateTime(const QDateTime &_d);  // Will produce the ADIF DATE format: "YYYYMMDD"
     QString getADIFDateFromQDate(const QDate &_d);          // Will produce the ADIF DATE format: "YYYYMMDD"
     QString getADIFTimeFromQDateTime(const QDateTime &_d);  // Will produce the ADIF TIME format: "HHMMSS"
+    QString getADIFTimeFromQTime(const QTime &_d);      // Will produce the ADIF TIME format: "HHMMSS"
 
     // Parse Date & Time from ADIF
     QDate getDateFromADIFDateString(const QString &_s);     // Expects an ADIF DATE format string: "YYYYMMDD"
@@ -161,6 +166,11 @@ public:
     QString getCabrilloDateFromQDate(const QDate &_d);          // Will produce the Cabrillo DATE format: "YYYY-MM-DD"
     QString getCabrilloTimeFromQDateTime(const QDateTime &_d);  // Will produce the Cabrillo TIME format: "HHMM"
 
+    // Parse QSO_COMPLETE from ADIF
+    QString getQSO_CompleteFromADIF(const QString &_s);     // Expect a string and returns 1char string for DB
+    QString getADIFQSO_CompleteFromDB(const QString &_s);   // Returns the ADIF QSO_COMPLETE
+
+
     QString getOnlineServiceName(OnLineProvider _service);
 
     bool isValidDistance(const double _d);
@@ -181,7 +191,6 @@ private:
     void init();
     void InitializeHash();
     void setLogColumnNames(); // Creates the map of column Names (should be called from init() )
-    bool processConfigLine(const QString &_line);
     QString getKLogDefaultDatabaseFile();
     //bool isCountrySuffix (const QString &_c);
     bool isAValidOperatingSuffix (const QString &_c);
@@ -197,7 +206,8 @@ private:
     QString getCheckedComplexCall(const QString &_c);
     void logEvent(const QString &_func, const QString &_msg, DebugLogLevel _level);
     //bool darkMode;
-    QString dbPath;
+    QString getDBPath();
+    //QString dbPath;
     QString softwareVersion;
     QString parentName;     // The class that instanciated this object.
 
